<?php
/**
 * The template for displaying comments
 *
 * @package Schematic
 */

do_action( 'csco_comments_before' );

$style = 'cs-entry__comments-collapse';

if ( 'page' === get_post_type() ) {
	if ( get_theme_mod( 'page_comments_simple', true ) ) {
		$style = 'cs-entry-comments-simple';
	}
} else {
	if ( get_theme_mod( 'post_comments_simple', true ) ) {
		$style = 'cs-entry-comments-simple';
	}
}

if ( get_option( 'comment_registration' ) && ! is_user_logged_in() ) {
	$style = 'cs-entry-comments-simple';
}

$comments_id = 'cs-entry-comments-simple' === $style ? 'comments' : 'comments-hidden';
?>

<div class="cs-entry__comments <?php echo esc_attr( $style ); ?>" id="<?php echo esc_attr( $comments_id ); ?>">

	<?php if ( have_comments() ) { ?>
		<div class="cs-entry__comments-list">
			<div class="cs-container">
				<div class="cs-main-content">
					<div class="cs-content-area">
						<div class="cs-entry__wrap">
							<div class="cs-entry__container">
								<?php if ( is_singular( 'post' ) && 'disabled' !== csco_get_page_sidebar() ) { ?>
									<div class="cs-sidebar__area"></div>
								<?php } ?>

								<div class="cs-entry__content-wrap">
									<div class="cs-entry__comments-list-inner">
										<?php
											$comments_number = get_comments_number();
											$section_heading = esc_html__( 'Comments', 'schematic' ) . ' <span>' . esc_html( $comments_number ) . '</span>';
											csco_section_heading( $section_heading, 'default' );
										?>

										<?php the_comments_navigation(); ?>

										<ol class="comment-list">
											<?php
											wp_list_comments(
												array(
													'style'       => 'ol',
													'short_ping'  => true,
													'avatar_size' => 60,
												)
											);
											?>
										</ol>

										<?php
										// If comments are closed and there are comments, let's leave a little note, shall we?
										if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) {
											?>
										<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'schematic' ); ?></p>
										<?php } ?>

										<?php the_comments_navigation(); ?>
									</div>
								</div>
							</div>
						</div>
					</div>

					<?php if ( csco_metabar_enabled() ) { ?>
						<div class="cs-metabar__area"></div>
					<?php } ?>

					<?php if ( ! is_singular( 'post' ) && 'disabled' !== csco_get_page_sidebar() ) { ?>
						<div class="cs-sidebar__area"></div>
					<?php } ?>
				</div>
			</div>
		</div>
	<?php } ?>

	<div class="cs-entry__comments-respond" data-scheme="dark">
		<div class="cs-container">
			<div class="cs-main-content">
				<div class="cs-content-area">
					<div class="cs-entry__wrap">
						<div class="cs-entry__container">
							<?php if ( is_singular( 'post' ) && 'disabled' !== csco_get_page_sidebar() ) { ?>
								<div class="cs-sidebar__area"></div>
							<?php } ?>

							<div class="cs-entry__content-wrap">
								<div class="cs-entry__comments-respond-inner">
									<?php comment_form(); ?>
								</div>
							</div>
						</div>
					</div>
				</div>

				<?php if ( csco_metabar_enabled() ) { ?>
					<div class="cs-metabar__area"></div>
				<?php } ?>

				<?php if ( ! is_singular( 'post' ) && 'disabled' !== csco_get_page_sidebar() ) { ?>
					<div class="cs-sidebar__area"></div>
				<?php } ?>
			</div>
		</div>
	</div>
</div>

<?php if ( 'cs-entry__comments-collapse' === $style ) : ?>
	<div class="cs-entry__comments-show" id="comments">
		<button><?php esc_html_e( 'View Comments', 'schematic' ); ?> (<?php echo intval( get_comments_number() ); ?>)</button>
	</div>
<?php endif; ?>

<?php do_action( 'csco_comments_after' ); ?>
