<?php
/**
 * Register Tile Type 1.
 *
 * @package Schematic
 */

/**
 * Register New Layout
 *
 * @param array $layouts List of layouts.
 */
function csco_canvas_register_layout_tile_type_1( $layouts = array() ) {

	$layout = 'tile-type-1';

	// Add new layout.
	$layouts[ $layout ] = array(
		'location'    => array(),
		'name'        => esc_html__( 'Tile 1', 'schematic' ),
		'template'    => get_template_directory() . '/template-parts/blocks/posts-area.php',
		'icon'        => '<svg fill="none" height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g stroke="#000"><rect height="42" rx="2" stroke-width="1.5" width="50" x="1" y="1"/><g stroke-linecap="round" stroke-linejoin="round"><path d="m5 5h12"/><path d="m31 5h12"/><path d="m5 35h7"/><path d="m31 35h7"/><path d="m5 37h16"/><path d="m31 37h16"/><path d="m5 39h7"/><path d="m31 39h7"/></g><path d="m26.75 1v42" stroke-width="1.5"/></g></svg>',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'schematic' ),
				'priority' => 5,
				'open'     => true,
			),
			'post-meta'  => array(
				'title'    => esc_html__( 'Meta Settings', 'schematic' ),
				'priority' => 10,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'schematic' ),
				'priority' => 10,
			),
		),
		'hide_fields' => csco_get_gutenberg_posts_hide_fields(),
		'fields'      => array_merge(
			csco_get_gutenberg_pagination_fields(),
			array(
				array(
					'key'            => 'columns',
					'label'          => esc_html__( 'Number of Columns', 'schematic' ),
					'section'        => 'general',
					'type'           => 'number',
					'min'            => 1,
					'max'            => 6,
					'default'        => 1,
					'default_laptop' => 1,
					'default_tablet' => 1,
					'default_mobile' => 1,
					'responsive'     => true,
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-columns',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'            => 'gap_between_columns',
					'label'          => esc_html__( 'Gap between Columns', 'schematic' ),
					'type'           => 'dimension',
					'section'        => 'general',
					'responsive'     => true,
					'default'        => '64px',
					'default_laptop' => '64px',
					'default_tablet' => '40px',
					'default_mobile' => '40px',
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-column-gap',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'            => 'gap_between_rows',
					'label'          => esc_html__( 'Gap between Rows', 'schematic' ),
					'type'           => 'dimension',
					'section'        => 'general',
					'responsive'     => true,
					'default'        => '64px',
					'default_laptop' => '64px',
					'default_tablet' => '40px',
					'default_mobile' => '40px',
					'output'         => array(
						array(
							'element'  => '$ .cs-posts-area__main',
							'property' => '--cs-posts-area-grid-row-gap',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'        => 'height',
					'label'      => esc_html__( 'Min Height', 'schematic' ),
					'type'       => 'dimension',
					'default'    => 'initial',
					'section'    => 'general',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cs-entry__outer',
							'property' => 'min-height',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'video',
					'label'   => esc_html__( 'Enable video backgrounds', 'schematic' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => false,
				),
				array(
					'key'             => 'video_controls',
					'label'           => esc_html__( 'Enable video controls', 'schematic' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'default'         => false,
					'active_callback' => array(
						array(
							'field'    => '$#video',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				// Thumbnail.
				array(
					'key'     => 'image_orientation',
					'label'   => esc_html__( 'Image Orientation', 'schematic' ),
					'section' => 'thumbnail',
					'type'    => 'select',
					'default' => 'stretch',
					'choices' => array(
						'stretch'        => esc_html__( 'Stretch', 'schematic' ),
						'wide'           => esc_html__( 'Wide', 'schematic' ),
						'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
						'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
						'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
						'portrait'       => esc_html__( 'Portrait 3:4', 'schematic' ),
						'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
						'square'         => esc_html__( 'Square', 'schematic' ),
					),
				),
				array(
					'key'     => 'image_size',
					'label'   => esc_html__( 'Images Size', 'schematic' ),
					'section' => 'thumbnail',
					'type'    => 'select',
					'default' => 'csco-large',
					'choices' => csco_get_list_available_image_sizes(),
				),
				array(
					'key'     => 'image_border_radius',
					'label'   => esc_html__( 'Image Border Radius', 'schematic' ),
					'section' => 'thumbnail',
					'type'    => 'dimension',
					'output'  => array(
						array(
							'element'  => '$',
							'property' => '--cs-thumbnail-border-radius',
						),
					),
				),
				// Typography.
				array(
					'key'            => 'typography_heading',
					'label'          => esc_html__( 'Heading Font Size', 'schematic' ),
					'section'        => 'typography',
					'type'           => 'dimension',
					'responsive'     => true,
					'default'        => '4.5rem',
					'default_laptop' => '2.75rem',
					'default_tablet' => '2.75rem',
					'default_mobile' => '2.5rem',
					'output'         => array(
						array(
							'element'  => '$ .cs-entry__title',
							'property' => '--cs-entry-title-font-size',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'        => 'typography_heading_line_height',
					'label'      => esc_html__( 'Heading Line Height', 'schematic' ),
					'section'    => 'typography',
					'type'       => 'dimension',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cs-entry__title',
							'property' => '--cs-font-headings-line-height',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'typography_heading_tag',
					'label'   => esc_html__( 'Heading Tag', 'schematic' ),
					'section' => 'typography',
					'type'    => 'select',
					'default' => 'h2',
					'choices' => array(
						'h1'  => esc_html__( 'H1', 'schematic' ),
						'h2'  => esc_html__( 'H2', 'schematic' ),
						'h3'  => esc_html__( 'H3', 'schematic' ),
						'h4'  => esc_html__( 'H4', 'schematic' ),
						'h5'  => esc_html__( 'H5', 'schematic' ),
						'h6'  => esc_html__( 'H6', 'schematic' ),
						'p'   => esc_html__( 'P', 'schematic' ),
						'div' => esc_html__( 'DIV', 'schematic' ),
					),
				),
			),
			// Primary Meta.
			csco_get_gutenberg_meta_fields(
				array(
					'section_name' => 'post-meta',
					'meta_compact' => false,
					'default'      => array(
						'category'     => true,
						'author'       => true,
						'date'         => true,
						'comments'     => false,
						'reading_time' => false,
						'views'        => false,
						'shares'       => false,
					),
				)
			)
		),
	);

	return $layouts;
}
add_filter( 'canvas_block_layouts_canvas/posts', 'csco_canvas_register_layout_tile_type_1' );
