<?php
/**
 * Register Tile Type 2.
 *
 * @package Schematic
 */

/**
 * Register New Layout
 *
 * @param array $layouts List of layouts.
 */
function csco_canvas_register_layout_tile_type_2( $layouts = array() ) {

	$layout = 'tile-type-2';

	// Add new layout.
	$layouts[ $layout ] = array(
		'location'    => array( 'section-full' ),
		'name'        => esc_html__( 'Tile 2', 'schematic' ),
		'template'    => get_template_directory() . "/template-parts/blocks/posts-area/{$layout}.php",
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd" transform="translate(1 1)"><rect height="42" rx="3" stroke="#2d2d2d" stroke-width="1.5" width="50"/><path d="m4 11h25v10h-25z" fill="#2d2d2d"/><path d="m7.5 14.5h17" stroke="#fff" stroke-linecap="round" stroke-linejoin="round"/><path d="m7.5 17.5h13" stroke="#fff" stroke-linecap="round" stroke-linejoin="round"/><g stroke="#2d2d2d"><path d="m5 24h5" stroke-linecap="round" stroke-linejoin="round"/><path d="m1.5 4.5h48" stroke-linecap="square" stroke-width="1.5"/><path d="m1 38h48" stroke-linecap="square" stroke-width="1.5"/><rect height="11" rx="1" stroke-width="1.5" transform="matrix(0 -1 1 0 -21 42)" width="5" x="8" y="26"/><rect height="11" rx="1" stroke-width="1.5" transform="matrix(0 -1 1 0 -6 57)" width="5" x="23" y="26"/><rect height="11" rx="1" stroke-width="1.5" transform="matrix(0 -1 1 0 8 71)" width="5" x="37" y="26"/></g></g></svg>',
		'sections'    => array(
			'general'       => array(
				'title'    => esc_html__( 'Block Settings', 'schematic' ),
				'priority' => 5,
				'open'     => true,
			),
			'large-meta'    => array(
				'title'    => esc_html__( 'Large Post Meta Settings', 'schematic' ),
				'priority' => 10,
			),
			'small-meta'    => array(
				'title'    => esc_html__( 'Small Post Meta Settings', 'schematic' ),
				'priority' => 10,
			),
			'small-heading' => array(
				'title'    => esc_html__( 'Small Post Heading', 'schematic' ),
				'priority' => 10,
			),
			'typography'    => array(
				'title'    => esc_html__( 'Typography Settings', 'schematic' ),
				'priority' => 10,
			),
		),
		'hide_fields' => csco_get_gutenberg_posts_hide_fields(),
		'fields'      => array_merge(
			array(
				array(
					'key'     => 'video',
					'label'   => esc_html__( 'Enable video backgrounds', 'schematic' ),
					'section' => 'general',
					'type'    => 'toggle',
					'default' => false,
				),
				array(
					'key'             => 'video_controls',
					'label'           => esc_html__( 'Display video controls', 'schematic' ),
					'section'         => 'general',
					'type'            => 'toggle',
					'default'         => false,
					'active_callback' => array(
						array(
							'field'    => '$#video',
							'operator' => '==',
							'value'    => true,
						),
					),
				),
				// Heading.
				array(
					'key'     => 'heading',
					'label'   => esc_html__( 'Heading', 'schematic' ),
					'section' => 'small-heading',
					'type'    => 'text',
					'default' => esc_html__( 'Featured', 'schematic' ),
				),
				array(
					'key'     => 'heading_label',
					'label'   => esc_html__( 'Link Label', 'schematic' ),
					'section' => 'small-heading',
					'type'    => 'text',
					'default' => esc_html__( 'View All', 'schematic' ),
				),
				array(
					'key'     => 'heading_url',
					'label'   => esc_html__( 'Link Url', 'schematic' ),
					'section' => 'small-heading',
					'type'    => 'text',
					'default' => '',
				),
				// Thumbnail.
				array(
					'key'     => 'image_size',
					'label'   => esc_html__( 'Large Post Image Size', 'schematic' ),
					'section' => 'thumbnail',
					'type'    => 'select',
					'default' => 'csco-extra-large',
					'choices' => csco_get_list_available_image_sizes(),
				),
				array(
					'key'     => 'small_image_orientation',
					'label'   => esc_html__( 'Small Image Orientation', 'schematic' ),
					'section' => 'thumbnail',
					'type'    => 'select',
					'default' => 'square',
					'choices' => array(
						'original'       => esc_html__( 'Original', 'schematic' ),
						'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
						'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
						'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
						'portrait'       => esc_html__( 'Portrait 3:4', 'schematic' ),
						'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
						'square'         => esc_html__( 'Square', 'schematic' ),
					),
				),
				array(
					'key'     => 'small_image_border_radius',
					'label'   => esc_html__( 'Small Post Image Border Radius', 'schematic' ),
					'section' => 'thumbnail',
					'type'    => 'dimension',
					'default' => '50%',
					'output'  => array(
						array(
							'element'  => '$ .cnvs-block-layout__sub-item',
							'property' => '--cs-thumbnail-border-radius',
						),
					),
				),
				// Typography.
				array(
					'key'            => 'typography_heading',
					'label'          => esc_html__( 'Large Post Heading Font Size', 'schematic' ),
					'section'        => 'typography',
					'type'           => 'dimension',
					'responsive'     => true,
					'default'        => '4.5rem',
					'default_laptop' => '2.75rem',
					'default_tablet' => '2.75rem',
					'default_mobile' => '2.5rem',
					'output'         => array(
						array(
							'element'  => '$ .cnvs-block-layout__item .cs-entry__title',
							'property' => '--cs-entry-title-font-size',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'        => 'typography_heading_line_height',
					'label'      => esc_html__( 'Large Post Heading Line Height', 'schematic' ),
					'section'    => 'typography',
					'type'       => 'dimension',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cnvs-block-layout__item .cs-entry__title',
							'property' => '--cs-font-headings-line-height',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'typography_heading_tag',
					'label'   => esc_html__( 'Large Post Heading Tag', 'schematic' ),
					'section' => 'typography',
					'type'    => 'select',
					'default' => 'h2',
					'choices' => array(
						'h1'  => esc_html__( 'H1', 'schematic' ),
						'h2'  => esc_html__( 'H2', 'schematic' ),
						'h3'  => esc_html__( 'H3', 'schematic' ),
						'h4'  => esc_html__( 'H4', 'schematic' ),
						'h5'  => esc_html__( 'H5', 'schematic' ),
						'h6'  => esc_html__( 'H6', 'schematic' ),
						'p'   => esc_html__( 'P', 'schematic' ),
						'div' => esc_html__( 'DIV', 'schematic' ),
					),
				),
				array(
					'key'        => 'small_typography_heading',
					'label'      => esc_html__( 'Small Post Heading Font Size', 'schematic' ),
					'section'    => 'typography',
					'type'       => 'dimension',
					'default'    => '1.5rem',
					'responsive' => true,
					'output'     => array(
						array(
							'element'  => '$ .cnvs-block-layout__sub-item .cs-entry__title',
							'property' => '--cs-entry-title-font-size',
							'suffix'   => '!important',
						),
					),
				),
				array(
					'key'     => 'small_typography_heading_tag',
					'label'   => esc_html__( 'Small Post Heading Tag', 'schematic' ),
					'section' => 'typography',
					'type'    => 'select',
					'default' => 'h2',
					'choices' => array(
						'h1'  => esc_html__( 'H1', 'schematic' ),
						'h2'  => esc_html__( 'H2', 'schematic' ),
						'h3'  => esc_html__( 'H3', 'schematic' ),
						'h4'  => esc_html__( 'H4', 'schematic' ),
						'h5'  => esc_html__( 'H5', 'schematic' ),
						'h6'  => esc_html__( 'H6', 'schematic' ),
						'p'   => esc_html__( 'P', 'schematic' ),
						'div' => esc_html__( 'DIV', 'schematic' ),
					),
				),
			),
			// Primary Meta.
			csco_get_gutenberg_meta_fields(
				array(
					'section_name' => 'large-meta',
					'default'      => array(
						'category'     => true,
						'author'       => true,
						'date'         => true,
						'comments'     => false,
						'reading_time' => false,
						'views'        => true,
						'shares'       => true,
					),
				)
			),
			// Small Meta.
			csco_get_gutenberg_meta_fields(
				array(
					'field_prefix' => 'small',
					'section_name' => 'small-meta',
					'default'      => array(
						'category'     => false,
						'author'       => true,
						'date'         => true,
						'comments'     => false,
						'reading_time' => false,
						'views'        => false,
						'shares'       => false,
					),
				)
			)
		),
	);

	return $layouts;
}
add_filter( 'canvas_block_layouts_canvas/posts', 'csco_canvas_register_layout_tile_type_2' );

/**
 * Change post query
 *
 * @param array $args       Args for post query.
 * @param array $attributes Block attributes.
 * @param array $options    Block options.
 */
function csco_canvas_posts_query_args_tile_type_2( $args, $attributes, $options ) {

	if ( 0 !== strpos( $attributes['layout'], 'tile-type-2' ) ) {
		return $args;
	}

	$args['posts_per_page'] = 5;
	$args['min_limit']      = 5;

	return $args;
}
add_filter( 'canvas_block_posts_query_args', 'csco_canvas_posts_query_args_tile_type_2', 10, 3 );
