<?php
/**
 * Editor Settings.
 *
 * @package Schematic
 */

/**
 * Register breakpoints for Canvas
 */
function csco_register_breakpoints() {
	return array(
		'mobile'  => 575,  // <= 575
		'tablet'  => 1279, // <= 1279
		'laptop'  => 1584, // <= 1584
		'desktop' => 1585, // >= 1585
	);
}
add_filter( 'canvas_register_breakpoints', 'csco_register_breakpoints' );

/**
 * Set section responsive max width
 */
function csco_canvas_section_responsive_max_width() {
	return 1730;
}
add_filter( 'canvas_section_responsive_max_width', 'csco_canvas_section_responsive_max_width' );

/**
 * Enqueue editor scripts
 */
function csco_block_editor_scripts() {
	wp_enqueue_script(
		'csco-editor-scripts',
		get_template_directory_uri() . '/assets/jsx/editor-scripts.js',
		array(
			'wp-editor',
			'wp-element',
			'wp-compose',
			'wp-data',
			'wp-plugins',
		),
		csco_get_theme_data( 'Version' ),
		true
	);
}
add_action( 'enqueue_block_editor_assets', 'csco_block_editor_scripts' );

/**
 * Adds classes to <div class="editor-styles-wrapper"> tag
 */
function csco_block_editor_wrapper() {

	$script_handle = 'cs-editor-wrapper';
	$script_file   = 'editor-wrapper.js';

	if ( 'enqueue_block_assets' === current_filter() ) {
		if ( ! ( is_admin() && ! is_customize_preview() ) ) {
			return;
		}

		$script_handle = 'cs-editor-iframe';
		$script_file   = 'editor-iframe.js';
	}

	$post_id = get_the_ID();

	if ( ! $post_id ) {
		return;
	}

	// Set post type.
	$post_type = sprintf( 'post-type-%s', get_post_type( $post_id ) );

	// Set page layout.
	$default_layout = csco_get_page_sidebar( $post_id, 'default' );
	$page_layout    = csco_get_page_sidebar( $post_id, false );

	if ( 'disabled' === $default_layout ) {
		$default_layout = 'cs-sidebar-disabled';
	} else {
		$default_layout = 'cs-sidebar-enabled';
	}

	if ( 'disabled' === $page_layout ) {
		$page_layout = 'cs-sidebar-disabled';
	} else {
		$page_layout = 'cs-sidebar-enabled';
	}

	// Post Sidebar.
	if ( 'post' === get_post_type( $post_id ) && csco_powerkit_module_enabled( 'share_buttons' ) && powerkit_share_buttons_exists( 'metabar-post' ) ) {
		$post_sidebar = 'cs-metabar-enabled';
	} else {
		$post_sidebar = 'cs-metabar-disabled';
	}

	// Section Heading.
	$section_heading = 'section-heading-default-' . get_theme_mod( 'section_heading', 'style-1' );

	// Set breakpoints.
	$breakpoints = array(
		'cs-breakpoint-up-576px'  => 576,
		'cs-breakpoint-up-768px'  => 768,
		'cs-breakpoint-up-1020px' => 1020,
		'cs-breakpoint-up-1200px' => 1200,
		'cs-breakpoint-up-1280px' => 1280,
		'cs-breakpoint-up-1420px' => 1420,
		'cs-breakpoint-up-1920px' => 1920,
	);

	wp_enqueue_script(
		$script_handle,
		get_template_directory_uri() . '/assets/jsx/' . $script_file,
		array(
			'wp-editor',
			'wp-element',
			'wp-compose',
			'wp-data',
			'wp-plugins',
		),
		csco_get_theme_data( 'Version' ),
		true
	);

	wp_localize_script(
		$script_handle,
		'cscoGWrapper',
		array(
			'post_type'       => $post_type,
			'default_layout'  => $default_layout,
			'page_layout'     => $page_layout,
			'post_sidebar'    => $post_sidebar,
			'section_heading' => $section_heading,
			'breakpoints'     => $breakpoints,
		)
	);
}
add_action( 'enqueue_block_editor_assets', 'csco_block_editor_wrapper' );
add_action( 'enqueue_block_assets', 'csco_block_editor_wrapper' );

/**
 * Change editor color palette.
 */
function csco_change_editor_color_palette() {
	// Editor Color Palette.
	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => esc_html__( 'Blue', 'schematic' ),
				'slug'  => 'blue',
				'color' => '#59BACC',
			),
			array(
				'name'  => esc_html__( 'Green', 'schematic' ),
				'slug'  => 'green',
				'color' => '#58AD69',
			),
			array(
				'name'  => esc_html__( 'Orange', 'schematic' ),
				'slug'  => 'orange',
				'color' => '#FFBC49',
			),
			array(
				'name'  => esc_html__( 'Red', 'schematic' ),
				'slug'  => 'red',
				'color' => '#e32c26',
			),
			array(
				'name'  => esc_html__( 'Pale Pink', 'schematic' ),
				'slug'  => 'pale-pink',
				'color' => '#f78da7',
			),
			array(
				'name'  => esc_html__( 'White', 'schematic' ),
				'slug'  => 'white',
				'color' => '#FFFFFF',
			),
			array(
				'name'  => esc_html__( 'Gray 50', 'schematic' ),
				'slug'  => 'gray-50',
				'color' => '#f8f9fa',
			),
			array(
				'name'  => esc_html__( 'Gray 100', 'schematic' ),
				'slug'  => 'gray-100',
				'color' => '#f8f9fb',
			),
			array(
				'name'  => esc_html__( 'Gray 200', 'schematic' ),
				'slug'  => 'gray-200',
				'color' => '#e9ecef',
			),
			array(
				'name'  => esc_html__( 'Secondary', 'schematic' ),
				'slug'  => 'secondary',
				'color' => get_theme_mod( 'color_secondary', '#818181' ),
			),
			array(
				'name'  => esc_html__( 'Primary', 'schematic' ),
				'slug'  => 'primary',
				'color' => '#141414',
			),
			array(
				'name'  => esc_html__( 'Black', 'schematic' ),
				'slug'  => 'black',
				'color' => '#000000',
			),
			array(
				'name'  => esc_html__( 'Accent', 'schematic' ),
				'slug'  => 'accent',
				'color' => '#ae856c',
			),
		)
	);
}
add_action( 'after_setup_theme', 'csco_change_editor_color_palette' );
