<?php
/**
 * Powerkit Filters
 *
 * @package Schematic
 */

/**
 * Register Social Links Templates
 *
 * @param array $templates List of Templates.
 */
function csco_powerkit_social_links_templates( $templates = array() ) {

	$new = array(
		'inline-alt' => array(
			'name' => 'Inline Alt',
		),
	);

	$templates = array_slice( $templates, 0, 1, true ) + $new + array_slice( $templates, 1, null, true );

	return $templates;
}
add_filter( 'powerkit_social_links_templates', 'csco_powerkit_social_links_templates', 99 );

/**
 * New Share Buttons Locations
 *
 * @param array $locations List of Locations.
 */
function csco_powerkit_new_share_buttons_locations( $locations = array() ) {

	$locations['after-post'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'After Post Content', 'schematic' ),
		'location'       => 'after-post',
		'mode'           => 'mixed',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'fields'         => array(
			'display_total'   => true,
			'display_count'   => true,
			'schemes'         => array( 'default', 'bold', 'bold-bg', 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'layout'         => 'default',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	$locations['metabar-post'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'Entry Metabar', 'schematic' ),
		'location'       => 'metabar-post',
		'mode'           => 'mixed',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'meta'           => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		// Display only the specified layouts and color schemes.
		'fields'         => array(
			'display_total'   => true,
			'display_count'   => true,
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'outside' ),
		),
		'layout'         => 'simple',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	$locations['post-meta'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'Post Meta', 'schematic' ),
		'location'       => 'post-meta',
		'mode'           => 'cached',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'meta'           => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		// Display only the specified layouts and color schemes.
		'fields'         => array(
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'display_total'  => false,
		'layout'         => 'simple',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	$locations['post-header'] = array(
		'shares'         => array( 'facebook', 'twitter', 'pinterest' ),
		'name'           => esc_html__( 'Post Header', 'schematic' ),
		'location'       => 'post-header',
		'mode'           => 'mixed',
		'before'         => '',
		'after'          => '',
		'display'        => true,
		'meta'           => array(
			'icons'  => true,
			'titles' => false,
			'labels' => true,
		),
		'fields'         => array(
			'display_total'   => false,
			'display_count'   => false,
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
			'count_locations' => array( 'inside' ),
		),
		'display_total'  => false,
		'layout'         => 'simple',
		'scheme'         => 'simple-light',
		'count_location' => 'inside',
	);

	return $locations;
}
add_filter( 'powerkit_share_buttons_locations', 'csco_powerkit_new_share_buttons_locations' );

/**
 * Change Share Buttons Locations
 *
 * @param array $locations List of Locations.
 */
function csco_powerkit_change_share_buttons_locations( $locations = array() ) {

	unset( $locations['before-content'] );
	unset( $locations['after-content'] );

	$locations['highlight-text'] = array(
		'shares'        => array( 'facebook', 'twitter', 'pinterest', 'mail' ),
		'name'          => '⚡ Highlight Text',
		'location'      => 'highlight-text',
		'mode'          => 'none',
		'before'        => '',
		'after'         => '',
		'meta'          => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		'fields'        => array(
			'display_total'   => false,
			'display_count'   => false,
			'title_locations' => array(),
			'count_locations' => array(),
			'label_locations' => array(),
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
		),
		'display_total' => false,
		'layout'        => 'simple',
		'scheme'        => 'simple-light',
		'attrs'         => 'data-scheme="default"',
	);

	$locations['blockquote'] = array(
		'shares'        => array( 'facebook', 'twitter' ),
		'name'          => '⭐ Blockquote',
		'location'      => 'blockquote',
		'mode'          => 'none',
		'before'        => '',
		'after'         => '',
		'meta'          => array(
			'icons'  => true,
			'titles' => false,
			'labels' => true,
		),
		'fields'        => array(
			'display_total'   => false,
			'display_count'   => false,
			'title_locations' => array(),
			'count_locations' => array(),
			'label_locations' => array(),
			'layouts'         => array( 'simple' ),
			'schemes'         => array( 'simple-light', 'bold-light' ),
		),
		'display_total' => false,
		'layout'        => 'simple',
		'scheme'        => 'simple-light',
	);

	$locations['mobile-share'] = array(
		'shares'   => array( 'facebook', 'pinterest', 'twitter', 'mail' ),
		'name'     => '📱 Mobile Share',
		'location' => 'mobile-share',
		'mode'     => 'none',
		'before'   => '',
		'after'    => '',
		'meta'     => array(
			'icons'  => true,
			'titles' => false,
			'labels' => false,
		),
		'fields'   => array(
			'display_total'   => false,
			'display_count'   => true,
			'title_locations' => array(),
			'count_locations' => array(),
			'label_locations' => array(),
			'schemes'         => array( 'default', 'simple-dark-back', 'bold-bg', 'bold' ),
			'layouts'         => array( 'horizontal', 'left-side', 'right-side', 'popup' ),
		),
		'layout'   => 'horizontal',
	);

	return $locations;
}
add_filter( 'powerkit_share_buttons_locations', 'csco_powerkit_change_share_buttons_locations', 9999 );

/**
 * Register Floated Share Buttons Location
 */
function csco_powerkit_widget_author_image_size() {
	return 'csco-thumbnail-uncropped';
}
add_filter( 'powerkit_widget_author_image_size', 'csco_powerkit_widget_author_image_size' );

/**
 * Change Contributors widget post author description length.
 */
function csco_powerkit_widget_contributors_description_length() {
	return 80;
}
add_filter( 'powerkit_widget_contributors_description_length', 'csco_powerkit_widget_contributors_description_length' );

/**
 * Change Default Template for featured posts
 *
 * @param array $templates The templates.
 */
function csco_powerkit_featured_posts_default( $templates = array() ) {

	$templates['list']['func']     = 'csco_powerkit_featured_default_template';
	$templates['numbered']['func'] = 'csco_powerkit_featured_default_template';
	$templates['large']['func']    = 'csco_powerkit_featured_default_template';

	return $templates;
}
add_filter( 'powerkit_featured_posts_templates', 'csco_powerkit_featured_posts_default' );

/**
 * Add new settings to Widget Posts
 *
 * @param array $settings The settings.
 */
function csco_powerkit_widget_posts_settings( $settings ) {

	$settings = array_merge(
		$settings,
		array(
			'image_orientation'  => 'square',
			'image_size'         => 'csco-smaller',
			'image_radius'       => '',
			'post_meta'          => array( 'date', 'comments' ),
			'featured_image'     => false,
			'post_meta_category' => true,
		)
	);

	return $settings;
}
add_filter( 'powerkit_widget_posts_settings', 'csco_powerkit_widget_posts_settings' );

/**
 * Add new field to Widget Posts
 *
 * @param object $context  The context.
 * @param array  $params   The params.
 * @param array  $instance Current settings.
 */
function csco_powerkit_widget_posts_form_after( $context, $params, $instance ) {
	$image_sizes = csco_get_list_available_image_sizes();
	?>
		<!-- Image Orientation -->
		<p>
			<label for="<?php echo esc_attr( $context->get_field_id( 'image_orientation' ) ); ?>"><?php esc_html_e( 'Image Orientation', 'schematic' ); ?>:</label>
			<select name="<?php echo esc_attr( $context->get_field_name( 'image_orientation' ) ); ?>" id="<?php echo esc_attr( $context->get_field_id( 'image_orientation' ) ); ?>" class="widefat">
				<option value="original" <?php selected( $params['image_orientation'], 'original' ); ?>><?php esc_html_e( 'Original', 'schematic' ); ?></option>
				<option value="landscape" <?php selected( $params['image_orientation'], 'landscape' ); ?>><?php esc_html_e( 'Landscape', 'schematic' ); ?></option>
				<option value="portrait" <?php selected( $params['image_orientation'], 'portrait' ); ?>><?php esc_html_e( 'Portrait', 'schematic' ); ?></option>
				<option value="square" <?php selected( $params['image_orientation'], 'square' ); ?>><?php esc_html_e( 'Square', 'schematic' ); ?></option>
			</select>
		</p>

		<!-- Images Size -->
		<p>
			<label for="<?php echo esc_attr( $context->get_field_id( 'image_size' ) ); ?>"><?php esc_html_e( 'Images Size', 'schematic' ); ?>:</label>
			<select name="<?php echo esc_attr( $context->get_field_name( 'image_size' ) ); ?>" id="<?php echo esc_attr( $context->get_field_id( 'image_size' ) ); ?>" class="widefat">
				<?php foreach ( $image_sizes as $key => $size ) { ?>
					<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $params['image_size'], $key ); ?>><?php echo esc_html( $size ); ?></option>
				<?php } ?>
			</select>
		</p>

		<!-- Image Border Radius -->
		<p>
			<label for="<?php echo esc_attr( $context->get_field_id( 'image_radius' ) ); ?>"><?php esc_html_e( 'Image Border Radius', 'schematic' ); ?>:</label>
			<input class="widefat" id="<?php echo esc_attr( $context->get_field_id( 'image_radius' ) ); ?>" class="checkbox" name="<?php echo esc_attr( $context->get_field_name( 'image_radius' ) ); ?>" type="text" value="<?php echo esc_attr( $params['image_radius'] ); ?>" />
		</p>

		<!-- Display Featured Image -->
		<p>
			<input id="<?php echo esc_attr( $context->get_field_id( 'featured_image' ) ); ?>" class="checkbox" name="<?php echo esc_attr( $context->get_field_name( 'featured_image' ) ); ?>" type="checkbox" <?php checked( (bool) $params['featured_image'] ); ?>>
			<label for="<?php echo esc_attr( $context->get_field_id( 'featured_image' ) ); ?>"><?php esc_html_e( 'Display featured image', 'schematic' ); ?></label>
		</p>
	<?php
}
add_action( 'powerkit_widget_posts_form_after', 'csco_powerkit_widget_posts_form_after', 10, 3 );

/**
 * Featured Default Template Callback
 *
 * @param  array $posts    Array of posts.
 * @param  array $params   Array of params.
 * @param  array $instance Widget instance.
 */
function csco_powerkit_featured_default_template( $posts, $params, $instance ) {

	$style = null;

	if ( $params['image_radius'] ) {
		$style = sprintf( '--cs-thumbnail-border-radius: %s;', $params['image_radius'] );
	}

	$overlay_class = 'cs-overlay-background';
	if ( 'list' === $params['template'] ) {
		$overlay_class .= ' cs-overlay-transparent';
	}

	$featured_image = false;
	if ( isset( $params['featured_image'] ) && $params['featured_image'] ) {
		$featured_image = true;
	}

	if ( 'list' === $params['template'] || 'numbered' === $params['template'] ) {
		?>
		<article <?php post_class(); ?> style="<?php echo esc_attr( $style ); ?>">
			<div class="cs-entry__outer">
				<?php if ( has_post_thumbnail() && $featured_image ) { ?>
					<div class="cs-entry__inner cs-entry__thumbnail cs-overlay-ratio cs-ratio-<?php echo esc_attr( $params['image_orientation'] ); ?>">
						<div class="<?php echo esc_attr( $overlay_class ); ?>">
							<?php the_post_thumbnail( $params['image_size'] ); ?>
						</div>

						<a class="cs-overlay-link" href="<?php echo esc_url( get_permalink() ); ?>"></a>
					</div>
				<?php } ?>

				<div class="cs-entry__inner cs-entry__content">
					<?php csco_get_post_meta( array( 'category' ), (bool) $params['post_meta_compact'], true, $params['post_meta'] ); ?>

					<h3 class="cs-entry__title">
						<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
					</h3>

					<?php csco_get_post_meta( array( 'author', 'date', 'comments', 'reading_time', 'views', 'shares' ), (bool) $params['post_meta_compact'], true, $params['post_meta'] ); ?>
				</div>
			</div>
		</article>
		<?php
	} elseif ( 'large' === $params['template'] ) {
		?>
		<article <?php post_class(); ?> style="<?php echo esc_attr( $style ); ?>">
			<div class="cs-entry__outer">
				<?php
				if ( has_post_thumbnail() && $featured_image ) {
					$params['thumbnail_meta'] = csco_get_post_meta( array( 'comments', 'reading_time', 'views', 'shares' ), false, false, $params['post_meta'] );
					?>
					<div class="cs-entry__inner cs-entry__thumbnail cs-entry__overlay cs-overlay-ratio cs-ratio-<?php echo esc_attr( $params['image_orientation'] ); ?>" data-scheme="inverse">
						<div class="cs-overlay-background cs-overlay-transparent">
							<?php the_post_thumbnail( $params['image_size'] ); ?>
						</div>

						<?php csco_the_post_format_icon(); ?>

						<a href="<?php echo esc_url( get_permalink() ); ?>" class="cs-overlay-link"></a>
					</div>
				<?php } ?>

				<div class="cs-entry__inner cs-entry__content">

					<?php csco_get_post_meta( array( 'category', 'author', 'date', 'comments', 'reading_time', 'views', 'shares' ), (bool) $params['post_meta_compact'], true, $params['post_meta'] ); ?>

					<?php the_title( '<h2 class="cs-entry__title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h2>' ); ?>

				</div>
			</div>
		</article>
		<?php
	}
}

/**
 * Change tiles featured categories
 *
 * @param string $locations List locations.
 */
function csco_powerkit_featured_categories_locations( $locations ) {

	$image_sizes = powerkit_get_list_available_image_sizes();

	$locations['grid'] = array(
		'name'        => esc_html__( 'Grid', 'schematic' ),
		'icon'        => '<svg height="44" viewBox="0 0 52 44" width="52" xmlns="http://www.w3.org/2000/svg"><g fill="none" fill-rule="evenodd" stroke="#2d2d2d"><rect height="42" rx="3" stroke-width="1.5" width="50" x="1" y="1"></rect><rect height="20" rx="1" stroke-width="1.5" width="40" x="6" y="6"></rect><g stroke-linecap="round" stroke-linejoin="round"><path d="m7 30.5h12"></path><path d="m7 33.5h28"></path><path d="m6.916667 36.5h9.166666"></path></g></g></svg>',
		'location'    => array(),
		'template'    => get_template_directory() . '/template-parts/blocks/categories-grid.php',
		'sections'    => array(
			'general'    => array(
				'title'    => esc_html__( 'Block Settings', 'schematic' ),
				'priority' => 5,
				'open'     => true,
			),
			'typography' => array(
				'title'    => esc_html__( 'Typography Settings', 'schematic' ),
				'priority' => 10,
			),
		),
		'hide_fields' => array(
			'number',
			'bgOverlay',
			'bgOpacityOverlay',
		),
		'fields'      => array(
			array(
				'key'            => 'columns',
				'label'          => esc_html__( 'Number of Columns', 'schematic' ),
				'section'        => 'general',
				'type'           => 'number',
				'min'            => 1,
				'max'            => 6,
				'default'        => 1,
				'default_laptop' => 1,
				'default_tablet' => 1,
				'default_mobile' => 1,
				'responsive'     => true,
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-columns',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'            => 'gap_posts',
				'label'          => esc_html__( 'Gap between Categories', 'schematic' ),
				'type'           => 'dimension',
				'section'        => 'general',
				'responsive'     => true,
				'default'        => '64px',
				'default_laptop' => '64px',
				'default_tablet' => '64px',
				'default_mobile' => '40px',
				'output'         => array(
					array(
						'element'  => '$ .cs-tiles-categories__wrap',
						'property' => '--cs-categories-grid-gap',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'      => 'orientation',
				'label'    => esc_html__( 'Image Orientation', 'schematic' ),
				'section'  => 'general',
				'type'     => 'select',
				'multiple' => false,
				'choices'  => array(
					'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
					'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
					'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
					'portrait'       => esc_html__( 'Portrait 3:4', 'schematic' ),
					'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
					'square'         => esc_html__( 'Square', 'schematic' ),
				),
				'default'  => 'landscape-3-2',
			),
			array(
				'key'     => 'image_size',
				'label'   => esc_html__( 'Image Size', 'schematic' ),
				'section' => 'general',
				'type'    => 'select',
				'default' => 'large',
				'choices' => $image_sizes,
			),
			// Typography.
			array(
				'key'        => 'typography_heading',
				'label'      => esc_html__( 'Heading Font Size', 'schematic' ),
				'section'    => 'typography',
				'type'       => 'dimension',
				'default'    => '1.5rem',
				'responsive' => true,
				'output'     => array(
					array(
						'element'  => '$ .cs-entry__title',
						'property' => 'font-size',
						'suffix'   => '!important',
					),
				),
			),
			array(
				'key'     => 'typography_heading_tag',
				'label'   => esc_html__( 'Heading Tag', 'schematic' ),
				'section' => 'typography',
				'type'    => 'select',
				'default' => 'h2',
				'choices' => array(
					'h1'  => esc_html__( 'H1', 'schematic' ),
					'h2'  => esc_html__( 'H2', 'schematic' ),
					'h3'  => esc_html__( 'H3', 'schematic' ),
					'h4'  => esc_html__( 'H4', 'schematic' ),
					'h5'  => esc_html__( 'H5', 'schematic' ),
					'h6'  => esc_html__( 'H6', 'schematic' ),
					'p'   => esc_html__( 'P', 'schematic' ),
					'div' => esc_html__( 'DIV', 'schematic' ),
				),
			),
		),
	);

	return $locations;
}
add_filter( 'powerkit_featured_categories_locations', 'csco_powerkit_featured_categories_locations', 99 );



/**
 * Simplify widget title
 *
 * @param string $widget_title Widget title.
 * @param string $title        Title.
 */
function csco_powerkit_simplify_widget_title( $widget_title, $title ) {
	$widget_title = sprintf( '<h5 class="pk-main-title">%s</h5>', $title );

	return $widget_title;
}
add_filter( 'powerkit_widget_about_title', 'csco_powerkit_simplify_widget_title', 10, 2 );
add_filter( 'powerkit_widget_author_title', 'csco_powerkit_simplify_widget_title', 10, 2 );

/**
 * Add exclude selectors of TOC
 *
 * @param string $list List selectors.
 */
function csco_powerkit_toc_exclude_selectors( $list ) {
	$list .= '|.cs-entry__title';

	return $list;
}
add_filter( 'pk_toc_exclude', 'csco_powerkit_toc_exclude_selectors' );

/**
 * PinIt exclude selector
 *
 * @param string $selectors List selectors.
 */
function csco_pinit_exclude_selector( $selectors ) {
	$selectors[] = '.pk-widget-author-bg';

	return $selectors;
}
add_filter( 'powerkit_pinit_exclude_selectors', 'csco_pinit_exclude_selector' );



/** Instagram Here */

/**
 * Footer Register Instagram Template
 *
 * @since    1.0.0
 * @access   private
 *
 * @param array $templates List of Templates.
 */
function csco_footer_instagram_default( $templates = array() ) {

	$templates['default']['func'] = 'csco_footer_instagram_template';

	return $templates;
}

/**
 * Footer Instagram Template
 *
 * @param array $feed      The instagram feed.
 * @param array $instagram The instagram items.
 * @param array $params    The user parameters.
 */
function csco_footer_instagram_template( $feed, $instagram, $params ) {

	if ( is_array( $instagram ) && $instagram ) {

		$type = get_theme_mod( 'footer_instagram_type', 'type-2' );

		$tag = apply_filters( 'powerkit_instagram_username_tag', 'h6' );

		?>

		<?php if ( $params['header'] ) { ?>
		<div class="pk-instagram-header">

			<?php if ( 'type-1' === $type || 'type-2' === $type || 'type-3' === $type || 'type-4' === $type ) { ?>

				<h5 class="cs-section-heading">
					<?php echo esc_html( get_theme_mod( 'footer_instagram_title', esc_html__( 'Instagram', 'schematic' ) ) ); ?>
				</h5>
				<div class="pk-instagram-container">
					<div class="pk-instagram-info">
						<?php if ( $feed['name'] !== $feed['username'] ) { ?>
							<<?php echo esc_html( $tag ); ?> class="pk-instagram-username pk-title pk-font-heading">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo wp_kses( $feed['username'], 'csco' ); ?>
								</a>
							</<?php echo esc_html( $tag ); ?>>
						<?php } elseif ( $feed['name'] ) { ?>
							<span class="pk-instagram-username pk-title pk-font-heading">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo esc_html( $feed['name'] ); ?>
								</a>
							</span>
						<?php } ?>

						<?php if ( is_int( $feed['following'] ) || is_int( $feed['followers'] ) ) { ?>
							<div class="pk-instagram-counters pk-color-secondary">
								<?php if ( is_int( $feed['following'] ) ) { ?>
									<div class="counter following">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['following'], 0 ) ); ?></span> <?php esc_html_e( 'Following', 'schematic' ); ?>
									</div>
								<?php } ?>

								<?php if ( is_int( $feed['followers'] ) ) { ?>
									<div class="counter followers">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['followers'], 0 ) ); ?></span> <?php esc_html_e( 'Followers', 'schematic' ); ?>
									</div>
								<?php } ?>
							</div>
						<?php } ?>
					</div>
				</div>

			<?php } elseif ( 'type-5' === $type ) { ?>

				<div class="pk-instagram-container">

					<?php if ( $feed['avatar_1x'] ) { ?>
						<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" class="pk-avatar-link" target="<?php echo esc_attr( $params['target'] ); ?>">
							<?php
								$image_avatar = sprintf(
									'<img src="%s" alt="avatar" class="pk-instagram-image">',
									esc_url( $feed['avatar_1x'] )
								);

								echo wp_kses_post( apply_filters( 'powerkit_lazy_process_images', $image_avatar ) );
							?>
						</a>
					<?php } ?>

					<div class="pk-instagram-info">
						<?php if ( $feed['name'] !== $feed['username'] ) { ?>
							<<?php echo esc_html( $tag ); ?>  class="pk-instagram-username pk-title pk-font-heading">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo wp_kses( $feed['username'], 'csco' ); ?>
								</a>
							</<?php echo esc_html( $tag ); ?>>
						<?php } ?>

						<?php if ( $feed['name'] ) { ?>
							<span class="pk-instagram-name pk-color-secondary">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo esc_html( $feed['name'] ); ?>
								</a>
							</span>
						<?php } ?>

						<?php if ( is_int( $feed['following'] ) || is_int( $feed['followers'] ) ) { ?>
							<div class="pk-instagram-counters pk-color-secondary">
								<?php if ( is_int( $feed['following'] ) ) { ?>
									<div class="counter following">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['following'], 0 ) ); ?></span> <?php esc_html_e( 'Following', 'schematic' ); ?>
									</div>
								<?php } ?>

								<?php if ( is_int( $feed['followers'] ) ) { ?>
									<div class="counter followers">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['followers'], 0 ) ); ?></span> <?php esc_html_e( 'Followers', 'schematic' ); ?>
									</div>
								<?php } ?>
							</div>
						<?php } ?>
					</div>
				</div>

				<?php
				$href = sprintf( 'https://www.instagram.com/%s/', $feed['username'] );
				$text = apply_filters( 'powerkit_instagram_follow', esc_html__( 'Follow', 'schematic' ) );
				?>
				<div class="wp-block-button">
					<a class="wp-block-button__link" href="<?php echo esc_url( $href ); ?>" target="_blank"><?php echo esc_html( $text ); ?></a>
				</div>

			<?php } ?>
			</div>
		<?php } ?>

		<div class="pk-instagram-items">
			<?php foreach ( $instagram as $key => $item ) { ?>

				<div class="pk-instagram-item">
					<a class="pk-instagram-link" href="<?php echo esc_url( $item['user_link'] ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
						<img src="<?php echo esc_attr( $item['user_image'] ); ?>" class="<?php echo esc_attr( $item['class'] ); ?>" alt="<?php echo esc_html( $item['description'] ); ?>" srcset="<?php echo esc_attr( $item['srcset'] ); ?>" sizes="<?php echo esc_attr( $item['sizes'] ); ?>">
						<?php if ( is_int( $item['likes'] ) || is_int( $item['comments'] ) ) { ?>

							<?php if ( 'type-3' !== $type ) { ?>
								<span class="pk-instagram-data">
									<span class="pk-instagram-meta">
										<?php if ( is_int( $item['likes'] ) ) { ?>
											<span class="pk-meta pk-meta-likes"><i class="pk-icon pk-icon-like"></i> <?php echo esc_attr( powerkit_abridged_number( $item['likes'] ) ); ?></span>
										<?php } ?>

										<?php if ( is_int( $item['comments'] ) ) { ?>
											<span class="pk-meta pk-meta-comments"><i class="pk-icon pk-icon-comment"></i> <?php echo esc_attr( powerkit_abridged_number( $item['comments'] ) ); ?></span>
										<?php } ?>
									</span>
								</span>
							<?php } ?>

						<?php } ?>

					</a>

					<?php if ( 'type-3' === $type ) { ?>

						<?php if ( is_int( $item['likes'] ) || is_int( $item['comments'] ) ) { ?>

							<span class="pk-instagram-data">
								<span class="pk-instagram-meta">
									<?php if ( is_int( $item['likes'] ) ) { ?>
										<span class="pk-meta pk-meta-likes"><i class="pk-icon pk-icon-like"></i> <?php echo esc_attr( powerkit_abridged_number( $item['likes'] ) ); ?></span>
									<?php } ?>

									<?php if ( is_int( $item['comments'] ) ) { ?>
										<span class="pk-meta pk-meta-comments"><i class="pk-icon pk-icon-comment"></i> <?php echo esc_attr( powerkit_abridged_number( $item['comments'] ) ); ?></span>
									<?php } ?>
								</span>
							</span>

						<?php } ?>

						<?php if ( $item['description'] ) { ?>
							<div class="pk-instagram-desc">
								<?php echo esc_html( $item['description'] ); ?>
							</div>
						<?php } ?>

					<?php } ?>

				</div>

			<?php } ?>
		</div>

		<?php if ( 'type-4' === $type && get_theme_mod( 'footer_instagram_footer', true ) ) { ?>
		<div class="pk-instagram-footer">
			<div class="pk-instagram-container">

				<?php if ( $feed['avatar_1x'] ) { ?>
					<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" class="pk-avatar-link" target="<?php echo esc_attr( $params['target'] ); ?>">
						<?php
							$image_avatar = sprintf(
								'<img src="%s" alt="avatar" class="pk-instagram-image">',
								esc_url( $feed['avatar_1x'] )
							);

							echo wp_kses_post( apply_filters( 'powerkit_lazy_process_images', $image_avatar ) );
						?>
					</a>
				<?php } ?>

				<div class="pk-instagram-info">
					<?php if ( $feed['name'] !== $feed['username'] ) { ?>
						<<?php echo esc_html( $tag ); ?>  class="pk-instagram-username pk-title pk-font-heading">
							<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
								<?php echo wp_kses( $feed['username'], 'csco' ); ?>
							</a>
						</<?php echo esc_html( $tag ); ?>>
					<?php } ?>

					<?php if ( $feed['name'] ) { ?>
						<span class="pk-instagram-name pk-color-secondary">
							<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
								<?php echo esc_html( $feed['name'] ); ?>
							</a>
						</span>
					<?php } ?>

					<?php if ( is_int( $feed['following'] ) || is_int( $feed['followers'] ) ) { ?>
						<div class="pk-instagram-counters pk-color-secondary">
							<?php if ( is_int( $feed['following'] ) ) { ?>
								<div class="counter following">
									<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['following'], 0 ) ); ?></span> <?php esc_html_e( 'Following', 'schematic' ); ?>
								</div>
							<?php } ?>

							<?php if ( is_int( $feed['followers'] ) ) { ?>
								<div class="counter followers">
									<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['followers'], 0 ) ); ?></span> <?php esc_html_e( 'Followers', 'schematic' ); ?>
								</div>
							<?php } ?>
						</div>
					<?php } ?>
				</div>
			</div>

			<?php
			$href = sprintf( 'https://www.instagram.com/%s/', $feed['username'] );
			$text = apply_filters( 'powerkit_instagram_follow', esc_html__( 'Follow', 'schematic' ) );
			?>
			<div class="wp-block-button is-style-outline">
				<a class="wp-block-button__link" href="<?php echo esc_url( $href ); ?>" target="_blank"><?php echo esc_html( $text ); ?></a>
			</div>

		</div>

			<?php
		} else {

			if ( $params['button'] && 'type-4' !== $type && 'type-5' !== $type ) {
				$href = sprintf( 'https://www.instagram.com/%s/', $feed['username'] );
				$text = apply_filters( 'powerkit_instagram_follow', esc_html__( 'Follow', 'schematic' ) );
				?>
				<div class="pk-instagram-footer">
					<div class="wp-block-button">
						<a class="wp-block-button__link" href="<?php echo esc_url( $href ); ?>" target="_blank"><?php echo esc_html( $text ); ?></a>
					</div>
				</div>
				<?php
			}
		}
	}
}

/**
 * Register instagram layouts
 *
 * @param array $layouts List of layouts.
 */
function csco_canvas_register_instagram_layouts( $layouts ) {

	$fields = array(
		array(
			'key'            => 'columns',
			'label'          => esc_html__( 'Number of Columns', 'schematic' ),
			'section'        => 'general',
			'type'           => 'number',
			'min'            => 1,
			'max'            => 8,
			'default'        => 4,
			'default_laptop' => 4,
			'default_tablet' => 4,
			'default_mobile' => 2,
			'responsive'     => true,
			'output'         => array(
				array(
					'element'  => '$ .pk-instagram-feed',
					'property' => '--cs-instagram-columns',
					'suffix'   => '!important',
				),
			),
		),
		array(
			'key'            => 'gap',
			'label'          => esc_html__( 'Gap between Posts', 'schematic' ),
			'type'           => 'dimension',
			'section'        => 'general',
			'responsive'     => true,
			'default'        => '0',
			'default_laptop' => '0',
			'default_tablet' => '',
			'default_mobile' => '',
			'output'         => array(
				array(
					'element'  => '$.cs-layout__instagram',
					'property' => '--cs-instagram-gap',
					'suffix'   => '!important',
				),
			),
		),
	);

	$template = get_template_directory() . '/template-parts/blocks/instagram-additional.php';

	$layouts['default'] = array(
		'name' => esc_html__( 'Type 1', 'schematic' ),
		'icon' => '
			<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
				<path fill="#000" d="M12 4.622c2.403 0 2.688.01 3.637.052.877.04 1.354.187 1.67.31.42.163.72.358 1.036.673.315.315.51.615.673 1.035.123.317.27.794.31 1.67.043.95.052 1.235.052 3.638s-.01 2.688-.052 3.637c-.04.877-.187 1.354-.31 1.67-.163.42-.358.72-.673 1.036-.315.315-.615.51-1.035.673-.317.123-.794.27-1.67.31-.95.043-1.234.052-3.638.052s-2.688-.01-3.637-.052c-.877-.04-1.354-.187-1.67-.31-.42-.163-.72-.358-1.036-.673-.315-.315-.51-.615-.673-1.035-.123-.317-.27-.794-.31-1.67-.043-.95-.052-1.235-.052-3.638s.01-2.688.052-3.637c.04-.877.187-1.354.31-1.67.163-.42.358-.72.673-1.036.315-.315.615-.51 1.035-.673.317-.123.794-.27 1.67-.31.95-.043 1.235-.052 3.638-.052M12 3c-2.444 0-2.75.01-3.71.054s-1.613.196-2.185.418c-.592.23-1.094.538-1.594 1.04-.5.5-.807 1-1.037 1.593-.223.572-.375 1.226-.42 2.184C3.01 9.25 3 9.555 3 12s.01 2.75.054 3.71.196 1.613.418 2.186c.23.592.538 1.094 1.038 1.594s1.002.808 1.594 1.038c.572.222 1.227.375 2.185.418.96.044 1.266.054 3.71.054s2.75-.01 3.71-.054 1.613-.196 2.186-.418c.592-.23 1.094-.538 1.594-1.038s.808-1.002 1.038-1.594c.222-.572.375-1.227.418-2.185.044-.96.054-1.266.054-3.71s-.01-2.75-.054-3.71-.196-1.613-.418-2.186c-.23-.592-.538-1.094-1.038-1.594s-1.002-.808-1.594-1.038c-.572-.222-1.227-.375-2.185-.418C14.75 3.01 14.445 3 12 3zm0 4.378c-2.552 0-4.622 2.07-4.622 4.622s2.07 4.622 4.622 4.622 4.622-2.07 4.622-4.622S14.552 7.378 12 7.378zM12 15c-1.657 0-3-1.343-3-3s1.343-3 3-3 3 1.343 3 3-1.343 3-3 3zm4.804-8.884c-.596 0-1.08.484-1.08 1.08s.484 1.08 1.08 1.08c.596 0 1.08-.484 1.08-1.08s-.483-1.08-1.08-1.08z" />
			</svg>
		',
	);

	$layouts['type-2'] = array(
		'name'        => esc_html__( 'Type 2', 'schematic' ),
		'icon'        => '
			<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
				<path fill="#000" d="M12 4.622c2.403 0 2.688.01 3.637.052.877.04 1.354.187 1.67.31.42.163.72.358 1.036.673.315.315.51.615.673 1.035.123.317.27.794.31 1.67.043.95.052 1.235.052 3.638s-.01 2.688-.052 3.637c-.04.877-.187 1.354-.31 1.67-.163.42-.358.72-.673 1.036-.315.315-.615.51-1.035.673-.317.123-.794.27-1.67.31-.95.043-1.234.052-3.638.052s-2.688-.01-3.637-.052c-.877-.04-1.354-.187-1.67-.31-.42-.163-.72-.358-1.036-.673-.315-.315-.51-.615-.673-1.035-.123-.317-.27-.794-.31-1.67-.043-.95-.052-1.235-.052-3.638s.01-2.688.052-3.637c.04-.877.187-1.354.31-1.67.163-.42.358-.72.673-1.036.315-.315.615-.51 1.035-.673.317-.123.794-.27 1.67-.31.95-.043 1.235-.052 3.638-.052M12 3c-2.444 0-2.75.01-3.71.054s-1.613.196-2.185.418c-.592.23-1.094.538-1.594 1.04-.5.5-.807 1-1.037 1.593-.223.572-.375 1.226-.42 2.184C3.01 9.25 3 9.555 3 12s.01 2.75.054 3.71.196 1.613.418 2.186c.23.592.538 1.094 1.038 1.594s1.002.808 1.594 1.038c.572.222 1.227.375 2.185.418.96.044 1.266.054 3.71.054s2.75-.01 3.71-.054 1.613-.196 2.186-.418c.592-.23 1.094-.538 1.594-1.038s.808-1.002 1.038-1.594c.222-.572.375-1.227.418-2.185.044-.96.054-1.266.054-3.71s-.01-2.75-.054-3.71-.196-1.613-.418-2.186c-.23-.592-.538-1.094-1.038-1.594s-1.002-.808-1.594-1.038c-.572-.222-1.227-.375-2.185-.418C14.75 3.01 14.445 3 12 3zm0 4.378c-2.552 0-4.622 2.07-4.622 4.622s2.07 4.622 4.622 4.622 4.622-2.07 4.622-4.622S14.552 7.378 12 7.378zM12 15c-1.657 0-3-1.343-3-3s1.343-3 3-3 3 1.343 3 3-1.343 3-3 3zm4.804-8.884c-.596 0-1.08.484-1.08 1.08s.484 1.08 1.08 1.08c.596 0 1.08-.484 1.08-1.08s-.483-1.08-1.08-1.08z" />
			</svg>
		',
		'location'    => array(),
		'sections'    => array(),
		'hide_fields' => array(
			'columns',
		),
		'fields'      => $fields,
		'template'    => $template,
	);

	$layouts['type-3'] = array(
		'name'        => esc_html__( 'Type 3', 'schematic' ),
		'icon'        => '
			<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
				<path fill="#000" d="M12 4.622c2.403 0 2.688.01 3.637.052.877.04 1.354.187 1.67.31.42.163.72.358 1.036.673.315.315.51.615.673 1.035.123.317.27.794.31 1.67.043.95.052 1.235.052 3.638s-.01 2.688-.052 3.637c-.04.877-.187 1.354-.31 1.67-.163.42-.358.72-.673 1.036-.315.315-.615.51-1.035.673-.317.123-.794.27-1.67.31-.95.043-1.234.052-3.638.052s-2.688-.01-3.637-.052c-.877-.04-1.354-.187-1.67-.31-.42-.163-.72-.358-1.036-.673-.315-.315-.51-.615-.673-1.035-.123-.317-.27-.794-.31-1.67-.043-.95-.052-1.235-.052-3.638s.01-2.688.052-3.637c.04-.877.187-1.354.31-1.67.163-.42.358-.72.673-1.036.315-.315.615-.51 1.035-.673.317-.123.794-.27 1.67-.31.95-.043 1.235-.052 3.638-.052M12 3c-2.444 0-2.75.01-3.71.054s-1.613.196-2.185.418c-.592.23-1.094.538-1.594 1.04-.5.5-.807 1-1.037 1.593-.223.572-.375 1.226-.42 2.184C3.01 9.25 3 9.555 3 12s.01 2.75.054 3.71.196 1.613.418 2.186c.23.592.538 1.094 1.038 1.594s1.002.808 1.594 1.038c.572.222 1.227.375 2.185.418.96.044 1.266.054 3.71.054s2.75-.01 3.71-.054 1.613-.196 2.186-.418c.592-.23 1.094-.538 1.594-1.038s.808-1.002 1.038-1.594c.222-.572.375-1.227.418-2.185.044-.96.054-1.266.054-3.71s-.01-2.75-.054-3.71-.196-1.613-.418-2.186c-.23-.592-.538-1.094-1.038-1.594s-1.002-.808-1.594-1.038c-.572-.222-1.227-.375-2.185-.418C14.75 3.01 14.445 3 12 3zm0 4.378c-2.552 0-4.622 2.07-4.622 4.622s2.07 4.622 4.622 4.622 4.622-2.07 4.622-4.622S14.552 7.378 12 7.378zM12 15c-1.657 0-3-1.343-3-3s1.343-3 3-3 3 1.343 3 3-1.343 3-3 3zm4.804-8.884c-.596 0-1.08.484-1.08 1.08s.484 1.08 1.08 1.08c.596 0 1.08-.484 1.08-1.08s-.483-1.08-1.08-1.08z" />
			</svg>
		',
		'location'    => array(),
		'sections'    => array(),
		'hide_fields' => array(
			'columns',
		),
		'fields'      => $fields,
		'template'    => $template,
	);

	$layouts['type-4'] = array(
		'name'        => esc_html__( 'Type 4', 'schematic' ),
		'icon'        => '
			<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
				<path fill="#000" d="M12 4.622c2.403 0 2.688.01 3.637.052.877.04 1.354.187 1.67.31.42.163.72.358 1.036.673.315.315.51.615.673 1.035.123.317.27.794.31 1.67.043.95.052 1.235.052 3.638s-.01 2.688-.052 3.637c-.04.877-.187 1.354-.31 1.67-.163.42-.358.72-.673 1.036-.315.315-.615.51-1.035.673-.317.123-.794.27-1.67.31-.95.043-1.234.052-3.638.052s-2.688-.01-3.637-.052c-.877-.04-1.354-.187-1.67-.31-.42-.163-.72-.358-1.036-.673-.315-.315-.51-.615-.673-1.035-.123-.317-.27-.794-.31-1.67-.043-.95-.052-1.235-.052-3.638s.01-2.688.052-3.637c.04-.877.187-1.354.31-1.67.163-.42.358-.72.673-1.036.315-.315.615-.51 1.035-.673.317-.123.794-.27 1.67-.31.95-.043 1.235-.052 3.638-.052M12 3c-2.444 0-2.75.01-3.71.054s-1.613.196-2.185.418c-.592.23-1.094.538-1.594 1.04-.5.5-.807 1-1.037 1.593-.223.572-.375 1.226-.42 2.184C3.01 9.25 3 9.555 3 12s.01 2.75.054 3.71.196 1.613.418 2.186c.23.592.538 1.094 1.038 1.594s1.002.808 1.594 1.038c.572.222 1.227.375 2.185.418.96.044 1.266.054 3.71.054s2.75-.01 3.71-.054 1.613-.196 2.186-.418c.592-.23 1.094-.538 1.594-1.038s.808-1.002 1.038-1.594c.222-.572.375-1.227.418-2.185.044-.96.054-1.266.054-3.71s-.01-2.75-.054-3.71-.196-1.613-.418-2.186c-.23-.592-.538-1.094-1.038-1.594s-1.002-.808-1.594-1.038c-.572-.222-1.227-.375-2.185-.418C14.75 3.01 14.445 3 12 3zm0 4.378c-2.552 0-4.622 2.07-4.622 4.622s2.07 4.622 4.622 4.622 4.622-2.07 4.622-4.622S14.552 7.378 12 7.378zM12 15c-1.657 0-3-1.343-3-3s1.343-3 3-3 3 1.343 3 3-1.343 3-3 3zm4.804-8.884c-.596 0-1.08.484-1.08 1.08s.484 1.08 1.08 1.08c.596 0 1.08-.484 1.08-1.08s-.483-1.08-1.08-1.08z" />
			</svg>
		',
		'location'    => array(),
		'sections'    => array(),
		'hide_fields' => array(
			'columns',
		),
		'fields'      => $fields,
		'template'    => $template,
	);

	$layouts['type-5'] = array(
		'name'        => esc_html__( 'Type 5', 'schematic' ),
		'icon'        => '
			<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24">
				<path fill="#000" d="M12 4.622c2.403 0 2.688.01 3.637.052.877.04 1.354.187 1.67.31.42.163.72.358 1.036.673.315.315.51.615.673 1.035.123.317.27.794.31 1.67.043.95.052 1.235.052 3.638s-.01 2.688-.052 3.637c-.04.877-.187 1.354-.31 1.67-.163.42-.358.72-.673 1.036-.315.315-.615.51-1.035.673-.317.123-.794.27-1.67.31-.95.043-1.234.052-3.638.052s-2.688-.01-3.637-.052c-.877-.04-1.354-.187-1.67-.31-.42-.163-.72-.358-1.036-.673-.315-.315-.51-.615-.673-1.035-.123-.317-.27-.794-.31-1.67-.043-.95-.052-1.235-.052-3.638s.01-2.688.052-3.637c.04-.877.187-1.354.31-1.67.163-.42.358-.72.673-1.036.315-.315.615-.51 1.035-.673.317-.123.794-.27 1.67-.31.95-.043 1.235-.052 3.638-.052M12 3c-2.444 0-2.75.01-3.71.054s-1.613.196-2.185.418c-.592.23-1.094.538-1.594 1.04-.5.5-.807 1-1.037 1.593-.223.572-.375 1.226-.42 2.184C3.01 9.25 3 9.555 3 12s.01 2.75.054 3.71.196 1.613.418 2.186c.23.592.538 1.094 1.038 1.594s1.002.808 1.594 1.038c.572.222 1.227.375 2.185.418.96.044 1.266.054 3.71.054s2.75-.01 3.71-.054 1.613-.196 2.186-.418c.592-.23 1.094-.538 1.594-1.038s.808-1.002 1.038-1.594c.222-.572.375-1.227.418-2.185.044-.96.054-1.266.054-3.71s-.01-2.75-.054-3.71-.196-1.613-.418-2.186c-.23-.592-.538-1.094-1.038-1.594s-1.002-.808-1.594-1.038c-.572-.222-1.227-.375-2.185-.418C14.75 3.01 14.445 3 12 3zm0 4.378c-2.552 0-4.622 2.07-4.622 4.622s2.07 4.622 4.622 4.622 4.622-2.07 4.622-4.622S14.552 7.378 12 7.378zM12 15c-1.657 0-3-1.343-3-3s1.343-3 3-3 3 1.343 3 3-1.343 3-3 3zm4.804-8.884c-.596 0-1.08.484-1.08 1.08s.484 1.08 1.08 1.08c.596 0 1.08-.484 1.08-1.08s-.483-1.08-1.08-1.08z" />
			</svg>
		',
		'location'    => array(),
		'sections'    => array(),
		'hide_fields' => array(
			'columns',
		),
		'fields'      => $fields,
		'template'    => $template,
	);

	return $layouts;
}
add_filter( 'canvas_block_layouts_canvas/instagram', 'csco_canvas_register_instagram_layouts' );

/**
 * Add Instagram Slider Template
 *
 * @param array $templates The templates.
 */
function csco_additional_register_instagram_template( $templates = array() ) {
	$templates['additional'] = array(
		'name' => esc_html__( 'Additional', 'schematic' ),
		'func' => 'csco_powerkit_instagram_additional_template',
	);

	return $templates;
}
add_filter( 'powerkit_instagram_templates', 'csco_additional_register_instagram_template' );

/**
 * Unset additional instagram template from widget.
 */
function csco_unset_widget_instagram_template() {
	if ( is_admin() ) {
		$current_screen = get_current_screen();
		if ( isset( $current_screen->base ) && 'widgets' === $current_screen->base ) {
			/**
			 * Unset additional instagram template.
			 *
			 * @param array $templates The templates.
			 */
			function csco_unset_additional_instagram_template( $templates = array() ) {
				unset( $templates['additional'] );
				return $templates;
			}
			add_filter( 'powerkit_instagram_templates', 'csco_unset_additional_instagram_template' );
		}
	}
}
add_action( 'current_screen', 'csco_unset_widget_instagram_template' );

/**
 * Instagram Additional Callback Function Template
 *
 * @param array $feed      The instagram feed.
 * @param array $instagram The instagram items.
 * @param array $params    The user parameters.
 */
function csco_powerkit_instagram_additional_template( $feed, $instagram, $params ) {

	if ( is_array( $instagram ) && $instagram ) {

		$type = $params['block_attrs']['layout'];

		$tag = apply_filters( 'powerkit_instagram_username_tag', 'h5' );
		?>

		<?php if ( $params['header'] ) { ?>
		<div class="pk-instagram-header">

			<?php if ( 'type-2' === $type || 'type-3' === $type || 'type-4' === $type ) { ?>
				<h5 class="cs-section-heading cnvs-block-section-heading">
					<span class="cnvs-section-title"><?php esc_html_e( 'Instagram', 'schematic' ); ?></span>
				</h5>
				<div class="pk-instagram-container">
					<div class="pk-instagram-info">
						<?php if ( $feed['name'] !== $feed['username'] ) { ?>
							<<?php echo esc_html( $tag ); ?> class="pk-instagram-username pk-title pk-font-heading">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo wp_kses( $feed['username'], 'csco' ); ?>
								</a>
							</<?php echo esc_html( $tag ); ?>>
						<?php } elseif ( $feed['name'] ) { ?>
							<span class="pk-instagram-username pk-title pk-font-heading">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo esc_html( $feed['name'] ); ?>
								</a>
							</span>
						<?php } ?>

						<?php if ( is_int( $feed['following'] ) || is_int( $feed['followers'] ) ) { ?>
							<div class="pk-instagram-counters pk-color-secondary">
								<?php if ( is_int( $feed['following'] ) ) { ?>
									<div class="counter following">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['following'], 0 ) ); ?></span> <?php esc_html_e( 'Following', 'schematic' ); ?>
									</div>
								<?php } ?>

								<?php if ( is_int( $feed['followers'] ) ) { ?>
									<div class="counter followers">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['followers'], 0 ) ); ?></span> <?php esc_html_e( 'Followers', 'schematic' ); ?>
									</div>
								<?php } ?>
							</div>
						<?php } ?>
					</div>
				</div>

			<?php } elseif ( 'type-5' === $type ) { ?>

				<div class="pk-instagram-container">

					<?php if ( $feed['avatar_1x'] ) { ?>
						<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" class="pk-avatar-link" target="<?php echo esc_attr( $params['target'] ); ?>">
							<?php
								$image_avatar = sprintf(
									'<img src="%s" alt="avatar" class="pk-instagram-image">',
									esc_url( $feed['avatar_1x'] )
								);

								echo wp_kses_post( apply_filters( 'powerkit_lazy_process_images', $image_avatar ) );
							?>
						</a>
					<?php } ?>

					<div class="pk-instagram-info">
						<?php if ( $feed['name'] !== $feed['username'] ) { ?>
							<<?php echo esc_html( $tag ); ?>  class="pk-instagram-username pk-title pk-font-heading">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo wp_kses( $feed['username'], 'csco' ); ?>
								</a>
							</<?php echo esc_html( $tag ); ?>>
						<?php } ?>

						<?php if ( $feed['name'] ) { ?>
							<span class="pk-instagram-name pk-color-secondary">
								<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
									<?php echo esc_html( $feed['name'] ); ?>
								</a>
							</span>
						<?php } ?>

						<?php if ( is_int( $feed['following'] ) || is_int( $feed['followers'] ) ) { ?>
							<div class="pk-instagram-counters pk-color-secondary">
								<?php if ( is_int( $feed['following'] ) ) { ?>
									<div class="counter following">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['following'], 0 ) ); ?></span> <?php esc_html_e( 'Following', 'schematic' ); ?>
									</div>
								<?php } ?>

								<?php if ( is_int( $feed['followers'] ) ) { ?>
									<div class="counter followers">
										<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['followers'], 0 ) ); ?></span> <?php esc_html_e( 'Followers', 'schematic' ); ?>
									</div>
								<?php } ?>
							</div>
						<?php } ?>
					</div>
				</div>

				<?php
				if ( $params['button'] ) {
					$href = sprintf( 'https://www.instagram.com/%s/', $feed['username'] );
					$text = apply_filters( 'powerkit_instagram_follow', esc_html__( 'Follow', 'schematic' ) );
					powerkit_print_gutenberg_blocks_button( $text, $href, $params['target'], 'button', $params['block_attrs'] );
				}
				?>

			<?php } ?>
			</div>
		<?php } ?>

		<div class="pk-instagram-items">
			<?php foreach ( $instagram as $key => $item ) { ?>

				<div class="pk-instagram-item">
					<a class="pk-instagram-link" href="<?php echo esc_url( $item['user_link'] ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
						<img src="<?php echo esc_attr( $item['user_image'] ); ?>" class="<?php echo esc_attr( $item['class'] ); ?>" alt="<?php echo esc_html( $item['description'] ); ?>" srcset="<?php echo esc_attr( $item['srcset'] ); ?>" sizes="<?php echo esc_attr( $item['sizes'] ); ?>">
						<?php if ( is_int( $item['likes'] ) || is_int( $item['comments'] ) ) { ?>

							<?php if ( 'type-3' !== $type ) { ?>
								<span class="pk-instagram-data">
									<span class="pk-instagram-meta">
										<?php if ( is_int( $item['likes'] ) ) { ?>
											<span class="pk-meta pk-meta-likes"><i class="pk-icon pk-icon-like"></i> <?php echo esc_attr( powerkit_abridged_number( $item['likes'] ) ); ?></span>
										<?php } ?>

										<?php if ( is_int( $item['comments'] ) ) { ?>
											<span class="pk-meta pk-meta-comments"><i class="pk-icon pk-icon-comment"></i> <?php echo esc_attr( powerkit_abridged_number( $item['comments'] ) ); ?></span>
										<?php } ?>
									</span>
								</span>
							<?php } ?>

						<?php } ?>

					</a>

					<?php if ( 'type-3' === $type ) { ?>

						<?php if ( is_int( $item['likes'] ) || is_int( $item['comments'] ) ) { ?>

							<span class="pk-instagram-data">
								<span class="pk-instagram-meta">
									<?php if ( is_int( $item['likes'] ) ) { ?>
										<span class="pk-meta pk-meta-likes"><i class="pk-icon pk-icon-like"></i> <?php echo esc_attr( powerkit_abridged_number( $item['likes'] ) ); ?></span>
									<?php } ?>

									<?php if ( is_int( $item['comments'] ) ) { ?>
										<span class="pk-meta pk-meta-comments"><i class="pk-icon pk-icon-comment"></i> <?php echo esc_attr( powerkit_abridged_number( $item['comments'] ) ); ?></span>
									<?php } ?>
								</span>
							</span>

						<?php } ?>

						<?php if ( $item['description'] ) { ?>
							<div class="pk-instagram-desc">
								<?php echo esc_html( $item['description'] ); ?>
							</div>
						<?php } ?>

					<?php } ?>

				</div>

			<?php } ?>
		</div>

		<?php if ( 'type-4' === $type ) { ?>
		<div class="pk-instagram-footer">
			<div class="pk-instagram-container">

				<?php if ( $feed['avatar_1x'] ) { ?>
					<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" class="pk-avatar-link" target="<?php echo esc_attr( $params['target'] ); ?>">
						<?php
							$image_avatar = sprintf(
								'<img src="%s" alt="avatar" class="pk-instagram-image">',
								esc_url( $feed['avatar_1x'] )
							);

							echo wp_kses_post( apply_filters( 'powerkit_lazy_process_images', $image_avatar ) );
						?>
					</a>
				<?php } ?>

				<div class="pk-instagram-info">
					<?php if ( $feed['name'] !== $feed['username'] ) { ?>
						<<?php echo esc_html( $tag ); ?>  class="pk-instagram-username pk-title pk-font-heading">
							<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
								<?php echo wp_kses( $feed['username'], 'csco' ); ?>
							</a>
						</<?php echo esc_html( $tag ); ?>>
					<?php } ?>

					<?php if ( $feed['name'] ) { ?>
						<span class="pk-instagram-name pk-color-secondary">
							<a href="<?php echo esc_url( sprintf( 'https://www.instagram.com/%s/', $feed['username'] ) ); ?>" target="<?php echo esc_attr( $params['target'] ); ?>">
								<?php echo esc_html( $feed['name'] ); ?>
							</a>
						</span>
					<?php } ?>

					<?php if ( is_int( $feed['following'] ) || is_int( $feed['followers'] ) ) { ?>
						<div class="pk-instagram-counters pk-color-secondary">
							<?php if ( is_int( $feed['following'] ) ) { ?>
								<div class="counter following">
									<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['following'], 0 ) ); ?></span> <?php esc_html_e( 'Following', 'schematic' ); ?>
								</div>
							<?php } ?>

							<?php if ( is_int( $feed['followers'] ) ) { ?>
								<div class="counter followers">
									<span class="number"><?php echo esc_html( powerkit_abridged_number( $feed['followers'], 0 ) ); ?></span> <?php esc_html_e( 'Followers', 'schematic' ); ?>
								</div>
							<?php } ?>
						</div>
					<?php } ?>
				</div>
			</div>

			<?php
			if ( $params['button'] ) {
				$href = sprintf( 'https://www.instagram.com/%s/', $feed['username'] );
				$text = apply_filters( 'powerkit_instagram_follow', esc_html__( 'Follow', 'schematic' ) );
				powerkit_print_gutenberg_blocks_button( $text, $href, $params['target'], 'button', $params['block_attrs'] );
			}
			?>

		</div>

			<?php
		} else {

			if ( $params['button'] && 'type-5' !== $type ) {
				$href = sprintf( 'https://www.instagram.com/%s/', $feed['username'] );
				$text = apply_filters( 'powerkit_instagram_follow', esc_html__( 'Follow', 'schematic' ) );
				?>
				<div class="pk-instagram-footer">
					<?php powerkit_print_gutenberg_blocks_button( $text, $href, $params['target'], 'button', $params['block_attrs'] ); ?>
				</div>
				<?php
			}
		}
	}
}

/**
 * Author Social Links
 *
 * @param mixed  $author    The author.
 * @param string $class     Class name of the wrapping <div>.
 * @param bool   $title     Title of the link.
 * @param bool   $only_data Output only data.
 */
function csco_powerkit_author_social_links( $author, $class = 'default', $title = false, $only_data = false ) {

	$links = powerkit_get_author_fields();

	$list = array();

	// Website.
	$url = get_the_author_meta( 'url', $author );

	if ( $url ) {
		$parse = wp_parse_url( $url );

		$list[] = array(
			'label' => isset( $parse['host'] ) ? $parse['host'] : $url,
			'key'   => 'website',
			'url'   => $url,
		);
	}

	// Loop through the array of social links.
	foreach ( $links as $key => $label ) {

		if ( isset( $author->$key ) ) {
			$author_url = $author->$key;
		} else {
			$author_url = get_the_author_meta( $key, $author );
		}

		if ( empty( $author_url ) ) {
			$author_url = get_post_meta( $author, sprintf( 'cap-%s', $key ), true );
		}

		$item_label = str_replace( 'Profile URL', '', $label );

		// Check if slug of a social icon is not empty.
		if ( $author_url ) {
			$list[] = array(
				'url'   => $author_url,
				'key'   => $key,
				'label' => trim( $item_label ),
			);
		}
	}

	if ( $only_data ) {
		return $list;
	}

	// Link Attributes.
	$target = get_option( 'powerkit_social_links_link_target', 'new' ) === 'new' ? '_blank' : '_self';
	$rel    = get_option( 'powerkit_social_links_nofollow' ) ? 'nofollow' : '';

	// Check if the list is not empty.
	if ( $list ) {
		?>
		<div class="pk-author-social-links pk-social-links-wrap pk-social-links-template-<?php echo esc_html( $class ); ?>">
			<div class="pk-social-links-items">
				<?php
				// Loop through the array of social links.
				foreach ( $list as $data ) {
					?>
						<div class="pk-social-links-item pk-social-links-<?php echo esc_html( $data['key'] ); ?>">
							<a href="<?php echo esc_url( $data['url'] ); ?>" class="pk-social-links-link" target="<?php echo esc_attr( $target ); ?>" rel="<?php echo esc_attr( $rel ); ?>">

								<?php if ( $title ) { ?>
									<span class="pk-social-links-title pk-font-primary"><?php echo esc_html( $data['label'] ); ?></span>
								<?php } ?>
							</a>
						</div>
					<?php
				}
				?>
			</div>
		</div>
		<?php
	}
}

/**
 * Change settings of opt-in-form
 *
 * @param array $blocks All registered blocks.
 */
function csco_change_settings_opt_in_form( $blocks ) {

	foreach ( $blocks as $key => $block ) {

		if ( 'canvas/opt-in-form' === $block['name'] ) {
			csco_smart_array_push(
				$blocks[ $key ]['fields'],
				array(
					'key'     => 'colorBasicButton',
					'label'   => esc_html__( 'Button Color', 'schematic' ),
					'section' => 'general',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$',
							'property' => '--cs-color-button-contrast-secondary',
							'suffix'   => '!important',
						),
					),
				),
				false,
				true
			);
			csco_smart_array_push(
				$blocks[ $key ]['fields'],
				array(
					'key'     => 'colorBasicButtonHover',
					'label'   => esc_html__( 'Button Color Hover', 'schematic' ),
					'section' => 'general',
					'type'    => 'color',
					'output'  => array(
						array(
							'element'  => '$',
							'property' => '--cs-color-button-contrast-secondary-hover',
							'suffix'   => '!important',
						),
					),
				),
				false,
				true
			);
		}
	}

	return $blocks;
}
add_filter( 'canvas_register_block_type', 'csco_change_settings_opt_in_form', 999 );

/**
 * Add Author Style Full
 *
 * @param array $blocks All registered blocks.
 */
function csco_add_author_style_full( $blocks ) {

	foreach ( $blocks as $key => $block ) {

		if ( 'canvas/author' === $block['name'] ) {

			$blocks[ $key ]['styles'] = array(
				array(
					'name'  => 'block-author-full',
					'label' => esc_html__( 'Full', 'schematic' ),
				),
			);

		}
	}

	return $blocks;
}
add_filter( 'canvas_register_block_type', 'csco_add_author_style_full', 999 );

/**
 * Exclude Inline Posts posts from related posts block
 *
 * @param array $args Array of WP_Query args.
 */
function csco_related_posts_args( $args ) {
	global $powerkit_inline_posts;
	if ( ! $powerkit_inline_posts ) {
		return $args;
	}
	$post__not_in         = $args['post__not_in'];
	$post__not_in         = array_unique( array_merge( $post__not_in, $powerkit_inline_posts ) );
	$args['post__not_in'] = $post__not_in;
	return $args;
}
