<?php
/**
 * Design
 *
 * @package Schematic
 */

CSCO_Customizer::add_panel(
	'colors',
	array(
		'title' => esc_html__( 'Colors', 'schematic' ),
	)
);

CSCO_Customizer::add_section(
	'colors_dark_mode',
	array(
		'title' => esc_html__( 'Dark Mode', 'schematic' ),
		'panel' => 'colors',
	)
);


CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'color_scheme',
		'label'    => esc_html__( 'Site Color Scheme', 'schematic' ),
		'section'  => 'colors_dark_mode',
		'default'  => 'system',
		'choices'  => array(
			'system' => esc_html__( 'User\'s system preference', 'schematic' ),
			'light'  => esc_html__( 'Light', 'schematic' ),
			'dark'   => esc_html__( 'Dark', 'schematic' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'color_scheme_toggle',
		'label'    => esc_html__( 'Enable dark/light mode toggle', 'schematic' ),
		'section'  => 'colors_dark_mode',
		'default'  => true,
	)
);

CSCO_Customizer::add_section(
	'colors_light_scheme',
	array(
		'title' => esc_html__( 'Light Scheme', 'schematic' ),
		'panel' => 'colors',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_site_background',
		'label'    => esc_html__( 'Site Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-site-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_header_background',
		'label'    => esc_html__( 'Header Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-header-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'color-alpha',
		'settings'    => 'color_header_elements_background',
		'label'       => esc_html__( 'Header Elements Background', 'schematic' ),
		'description' => esc_html__( 'Background color for Fullscreen Menu, Submenu, Search and Multi Columns.', 'schematic' ),
		'section'     => 'colors_light_scheme',
		'default'     => '#f8f8f8',
		'alpha'       => true,
		'output'      => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-submenu-background',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-search-background',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-fullscreen-menu-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_offcanvas_background',
		'label'    => esc_html__( 'Offcanvas Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#f8f8f8',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-offcanvas-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_footer_background',
		'label'    => esc_html__( 'Footer Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-site-scheme="default"]',
				'property' => '--cs-color-footer-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_overlay',
		'label'    => esc_html__( 'Overlay Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => 'rgba(0,0,0,0.5)',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-overlay-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Colors */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_light_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_accent',
		'label'    => esc_html__( 'Primary Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ae856c',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-accent',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-contrast-secondary-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_secondary',
		'label'    => esc_html__( 'Secondary Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#a1a1a1',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-palette-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Link Color */

CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_light_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_link',
		'label'    => esc_html__( 'Post Content Link Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#141414',
		'context'  => array( 'editor', 'front' ),
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-link',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_link_hover',
		'label'    => esc_html__( 'Post Content Link Hover Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#141414',
		'context'  => array( 'editor', 'front' ),
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-link-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Button */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_light_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button',
		'label'    => esc_html__( 'Button Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#141414',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_contrast',
		'label'    => esc_html__( 'Button Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_hover',
		'label'    => esc_html__( 'Button Hover Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#3e3e3e',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_hover_contrast',
		'label'    => esc_html__( 'Button Hover Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-button-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Category  */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_light_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_category',
		'label'    => esc_html__( 'Category Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#141414',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-category-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_category_hover',
		'label'    => esc_html__( 'Category Hover Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#a1a1a1',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-category-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Meta */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_light_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_meta',
		'label'    => esc_html__( 'Post Meta Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#141414',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-post-meta',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_meta_link',
		'label'    => esc_html__( 'Post Meta Link Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#141414',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-post-meta-link',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_meata_link_hover',
		'label'    => esc_html__( 'Post Meta Link Hover Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#818181',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-post-meta-link-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);


/** Badges */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_light_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_primary',
		'label'    => esc_html__( 'Badge Primary Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-primary"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_primary_background',
		'label'    => esc_html__( 'Badge Primary Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#000000',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-primary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_secondary',
		'label'    => esc_html__( 'Badge Secondary Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#7a7a7a',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-secondary"]',
				'property' => '--cs-color-badge-light-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_secodary_background',
		'label'    => esc_html__( 'Badge Secondary Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ededed',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-secondary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_success',
		'label'    => esc_html__( 'Badge Success Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-success"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_success_background',
		'label'    => esc_html__( 'Badge Success Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#8EB096',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-success',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_danger',
		'label'    => esc_html__( 'Badge Danger Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-danger"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_danger_background',
		'label'    => esc_html__( 'Badge Danger Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#b39295',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-danger',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_warning',
		'label'    => esc_html__( 'Badge Warning Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-warning"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_warning_background',
		'label'    => esc_html__( 'Badge Warning Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#cac6b4',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-warning',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_info',
		'label'    => esc_html__( 'Badge Info Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-info"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_info_background',
		'label'    => esc_html__( 'Badge Info Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#89AFB5',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-info',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_dark',
		'label'    => esc_html__( 'Badge Dark Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-dark"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_dark_background',
		'label'    => esc_html__( 'Badge Dark Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#000000',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-dark',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_light',
		'label'    => esc_html__( 'Badge Light Color', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#000000',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="default"] [class*="-badge"][class*="-light"]',
				'property' => '--cs-color-badge-light-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_light_background',
		'label'    => esc_html__( 'Badge Light Background', 'schematic' ),
		'section'  => 'colors_light_scheme',
		'default'  => '#fafafa',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => ':root, [data-scheme="default"]',
				'property' => '--cs-color-badge-light',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_section(
	'colors_dark_scheme',
	array(
		'title' => esc_html__( 'Dark Scheme', 'schematic' ),
		'panel' => 'colors',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_site_background_dark',
		'label'    => esc_html__( 'Site Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#1c1c1c',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-site-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_header_background_dark',
		'label'    => esc_html__( 'Header Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#1c1c1c',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-header-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'color-alpha',
		'settings'    => 'color_header_elements_background_dark',
		'label'       => esc_html__( 'Header Elements Background', 'schematic' ),
		'description' => esc_html__( 'Background color for Fullscreen Menu, Submenu, Search and Multi Columns.', 'schematic' ),
		'section'     => 'colors_dark_scheme',
		'default'     => '#292929',
		'alpha'       => true,
		'output'      => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-submenu-background',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-search-background',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-multi-column-background',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-fullscreen-menu-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_offcanvas_background_dark',
		'label'    => esc_html__( 'Offcanvas Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#1c1c1c',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-offcanvas-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);


CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_footer_background_dark',
		'label'    => esc_html__( 'Footer Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#1c1c1c',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-footer-background',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Colors Dark */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_dark_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_accent_dark',
		'label'    => esc_html__( 'Primary Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#A1A1A1',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-accent',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-contrast-secondary-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_secondary_dark',
		'label'    => esc_html__( 'Secondary Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#a1a1a1',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-palette-color-secondary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Link Color Dark */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_dark_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_link_dark',
		'label'    => esc_html__( 'Post Content Link Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'context'  => array( 'editor', 'front' ),
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-link',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_link_hover_dark',
		'label'    => esc_html__( 'Post Content Link Hover Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'context'  => array( 'editor', 'front' ),
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-site-scheme="dark"]',
				'property' => '--cs-color-link-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Button Dark */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_dark_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_dark',
		'label'    => esc_html__( 'Button Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_contrast_dark',
		'label'    => esc_html__( 'Button Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#141414',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_hover_dark',
		'label'    => esc_html__( 'Button Hover Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#a4a4a5',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_hover_contrast_dark',
		'label'    => esc_html__( 'Button Hover Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#141414',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_button_dark',
		'label'    => esc_html__( 'Secondary Button Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-button',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Category Dark */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_dark_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_category_dark',
		'label'    => esc_html__( 'Category Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-category-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_category_hover_dark',
		'label'    => esc_html__( 'Category Hover Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#a1a1a1',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-category-hover-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/** Meta Dark */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_dark_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_meta_dark',
		'label'    => esc_html__( 'Post Meta Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-post-meta',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_meta_link_dark',
		'label'    => esc_html__( 'Post Meta Link Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-post-meta-link',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_meata_link_hover_dark',
		'label'    => esc_html__( 'Post Meta Link Hover Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#818181',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-post-meta-link-hover',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);


/** Badges Dark */
CSCO_Customizer::add_field(
	array(
		'type'     => 'divider',
		'settings' => wp_unique_id( 'divider' ),
		'section'  => 'colors_dark_scheme',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_primary_dark',
		'label'    => esc_html__( 'Badge Primary Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-primary"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_primary_background_dark',
		'label'    => esc_html__( 'Badge Primary Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#000000',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-primary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_secondary_dark',
		'label'    => esc_html__( 'Badge Secondary Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#7a7a7a',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-secondary"]',
				'property' => '--cs-color-badge-light-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_secodary_background_dark',
		'label'    => esc_html__( 'Badge Secondary Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ededed',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-secondary',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_success_dark',
		'label'    => esc_html__( 'Badge Success Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-success"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_success_background_dark',
		'label'    => esc_html__( 'Badge Success Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#8EB096',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-success',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_danger_dark',
		'label'    => esc_html__( 'Badge Danger Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-danger"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_danger_background_dark',
		'label'    => esc_html__( 'Badge Danger Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#b39295',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-danger',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_warning_dark',
		'label'    => esc_html__( 'Badge Warning Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-warning"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_warning_background_dark',
		'label'    => esc_html__( 'Badge Warning Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#cac6b4',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-warning',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_info_dark',
		'label'    => esc_html__( 'Badge Info Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-info"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_info_background_dark',
		'label'    => esc_html__( 'Badge Info Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#89AFB5',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-info',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_dark_dark',
		'label'    => esc_html__( 'Badge Dark Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#ffffff',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-dark"]',
				'property' => '--cs-color-badge-dark-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_dark_background_dark',
		'label'    => esc_html__( 'Badge Dark Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => 'rgba(255,255,255,0.7)',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-dark',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_light_dark',
		'label'    => esc_html__( 'Badge Light Color', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => '#020202',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"] [class*="-badge"][class*="-light"]',
				'property' => '--cs-color-badge-light-contrast',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'color-alpha',
		'settings' => 'color_badge_light_background_dark',
		'label'    => esc_html__( 'Badge Light Background', 'schematic' ),
		'section'  => 'colors_dark_scheme',
		'default'  => 'rgb(238,238,238)',
		'alpha'    => true,
		'output'   => array(
			array(
				'element'  => '[data-scheme="dark"]',
				'property' => '--cs-color-badge-light',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

/**
 * Border Radius
 */
CSCO_Customizer::add_section(
	'colors_border_radius',
	array(
		'title' => esc_html__( 'Border Radius', 'schematic' ),
		'panel' => 'colors',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'              => 'dimension',
		'settings'          => 'design_layout elements_border_radius',
		'label'             => esc_html__( 'Layout Elements', 'schematic' ),
		'description'       => esc_html__( 'Used on Form Elements, Blockquotes, Block Groups etc.', 'schematic' ),
		'section'           => 'colors_border_radius',
		'default'           => '4px',
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-layout-elements-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'              => 'dimension',
		'settings'          => 'design_thumbnail_border_radius',
		'label'             => esc_html__( 'Thumbnail Border Radius', 'schematic' ),
		'section'           => 'colors_border_radius',
		'default'           => '0px',
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-thumbnail-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'              => 'dimension',
		'settings'          => 'design_button_border_radius',
		'label'             => esc_html__( 'Button Border Radius', 'schematic' ),
		'description'       => esc_html__( 'Used on Buttons, Pagination, Badges and Tags.', 'schematic' ),
		'section'           => 'colors_border_radius',
		'default'           => '50px',
		'sanitize_callback' => 'esc_html',
		'output'            => array(
			array(
				'element'  => ':root',
				'property' => '--cs-button-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root',
				'property' => '--cs-pagination-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root',
				'property' => '--cs-badge-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
			array(
				'element'  => ':root',
				'property' => '--cs-tag-border-radius',
				'context'  => array( 'editor', 'front' ),
			),
		),
	)
);
