<?php
/**
 * Footer Settings
 *
 * @package Schematic
 */

CSCO_Customizer::add_section(
	'footer',
	array(
		'title' => esc_html__( 'Footer Settings', 'schematic' ),
	)
);


CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'footer_collapsible_common',
		'label'       => esc_html__( 'Common', 'schematic' ),
		'section'     => 'footer',
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'footer_layout',
		'label'    => esc_html__( 'Layout', 'schematic' ),
		'section'  => 'footer',
		'default'  => 'one',
		'choices'  => apply_filters( 'csco_footer_layouts', array(
			'one'   => esc_html__( 'Footer 1', 'schematic' ),
			'two'   => esc_html__( 'Footer 2', 'schematic' ),
			'three' => esc_html__( 'Footer 3', 'schematic' ),
		) ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'              => 'textarea',
		'settings'          => 'footer_text',
		'label'             => esc_html__( 'Footer Text', 'schematic' ),
		'section'           => 'footer',
		'default'           => '',
		'sanitize_callback' => 'csco_kses',
		'active_callback'   => array(
			array(
				'setting'  => 'footer_layout',
				'operator' => '!=',
				'value'    => 'three',
			),
		),
	)
);

if ( csco_powerkit_module_enabled( 'social_links' ) ) {
	CSCO_Customizer::add_field(
		array(
			'type'     => 'collapsible',
			'settings' => 'footer_collapsible_social',
			'label'    => esc_html__( 'Social Links', 'schematic' ),
			'section'  => 'footer',
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'     => 'checkbox',
			'settings' => 'footer_social_links',
			'label'    => esc_html__( 'Display social links', 'schematic' ),
			'section'  => 'footer',
			'default'  => false,

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'text',
			'settings'        => 'footer_social_links_label',
			'label'           => esc_html__( 'Heading', 'schematic' ),
			'section'         => 'footer',
			'default'         => esc_html__( 'Networking', 'schematic' ),
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_layout',
					'operator' => '==',
					'value'    => 'one',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'select',
			'settings'        => 'footer_social_links_scheme',
			'label'           => esc_html__( 'Color scheme', 'schematic' ),
			'section'         => 'footer',
			'default'         => 'light',
			'choices'         => array(
				'default' => esc_html__( 'Light', 'schematic' ),
				'bold'    => esc_html__( 'Bold', 'schematic' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'number',
			'settings'        => 'footer_social_links_maximum',
			'label'           => esc_html__( 'Maximum Number of Social Links', 'schematic' ),
			'section'         => 'footer',
			'default'         => 4,
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_social_links_counts',
			'label'           => esc_html__( 'Display counts', 'schematic' ),
			'section'         => 'footer',
			'default'         => true,
			'active_callback' => array(
				array(
					'setting'  => 'footer_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Customizer::add_field(
		array(
			'type'     => 'collapsible',
			'settings' => 'footer_collapsible_subscription',
			'label'    => esc_html__( 'Subscription Form', 'schematic' ),
			'section'  => 'footer',

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'     => 'checkbox',
			'settings' => 'footer_subscribe',
			'label'    => esc_html__( 'Display subscribe section', 'schematic' ),
			'section'  => 'footer',
			'default'  => false,

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_subscribe_name',
			'label'           => esc_html__( 'Display first name field', 'schematic' ),
			'section'         => 'footer',
			'default'         => true,
			'active_callback' => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'              => 'text',
			'settings'          => 'footer_subscribe_title',
			'label'             => esc_html__( 'Title', 'schematic' ),
			'section'           => 'footer',
			'default'           => esc_html__( 'Subscribe to our newsletter and get posts every week', 'schematic' ),

			'sanitize_callback' => 'csco_kses',
			'active_callback'   => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'              => 'text',
			'settings'          => 'footer_subscribe_text',
			'label'             => esc_html__( 'Text', 'schematic' ),
			'section'           => 'footer',
			'default'           => esc_html__( 'Get notified of the best deals on our WordPress themes.', 'schematic' ),

			'sanitize_callback' => 'csco_kses',
			'active_callback'   => array(
				array(
					'setting'  => 'footer_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

if ( csco_powerkit_module_enabled( 'instagram_integration' ) ) {
	CSCO_Customizer::add_field(
		array(
			'type'     => 'collapsible',
			'settings' => 'footer_collapsible_instagram',
			'label'    => esc_html__( 'Instagram', 'schematic' ),
			'section'  => 'footer',

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'     => 'text',
			'settings' => 'footer_instagram_username',
			'label'    => esc_html__( 'Instagram Username', 'schematic' ),
			'section'  => 'footer',
			'default'  => '',

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'radio',
			'settings'        => 'footer_instagram_type',
			'label'           => esc_html__( 'Type', 'schematic' ),
			'section'         => 'footer',
			'default'         => 'type-2',
			'choices'         => array(
				'default' => esc_html__( 'Type 1', 'schematic' ),
				'type-2'  => esc_html__( 'Type 2', 'schematic' ),
				'type-3'  => esc_html__( 'Type 3', 'schematic' ),
				'type-4'  => esc_html__( 'Type 4', 'schematic' ),
				'type-5'  => esc_html__( 'Type 5', 'schematic' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'number',
			'settings'        => 'footer_instagram_columns_desktop',
			'label'           => esc_html__( 'Number of Columns Desktop', 'schematic' ),
			'section'         => 'footer',
			'default'         => 4,
			'input_attrs'     => array(
				'min'  => 1,
				'max'  => 8,
				'step' => 1,
			),
			'output'          => array(
				array(
					'element'  => '.cs-footer-instagram',
					'property' => '--cs-instagram-columns',
					'suffix'   => '!important',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'number',
			'settings'        => 'footer_instagram_columns_tablet',
			'label'           => esc_html__( 'Number of Columns Tablet', 'schematic' ),
			'section'         => 'footer',
			'default'         => 4,
			'input_attrs'     => array(
				'min'  => 1,
				'max'  => 8,
				'step' => 1,
			),
			'output'          => array(
				array(
					'element'     => '.cs-footer-instagram',
					'property'    => '--cs-instagram-columns',
					'media_query' => '@media (max-width: 1019px)',
					'suffix'      => '!important',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'number',
			'settings'        => 'footer_instagram_columns_mobile',
			'label'           => esc_html__( 'Number of Columns Mobile', 'schematic' ),
			'section'         => 'footer',
			'default'         => 2,
			'input_attrs'     => array(
				'min'  => 1,
				'max'  => 8,
				'step' => 1,
			),
			'output'          => array(
				array(
					'element'     => '.cs-footer-instagram',
					'property'    => '--cs-instagram-columns',
					'media_query' => '@media (max-width: 599px)',
					'suffix'      => '!important',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'number',
			'settings'        => 'footer_instagram_number',
			'label'           => esc_html__( 'Number of images (maximum 16)', 'schematic' ),
			'section'         => 'footer',
			'default'         => 4,
			'input_attrs'     => array(
				'min'  => 1,
				'max'  => 16,
				'step' => 1,
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'dimension',
			'settings'        => 'footer_instagram_gap',
			'label'           => esc_html__( 'Gap between Posts', 'schematic' ),
			'section'         => 'footer',
			'default'         => '0px',
			'output'          => array(
				array(
					'element'  => '.cs-footer-instagram',
					'property' => '--cs-instagram-gap',
					'suffix'   => '!important',
				),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'select',
			'settings'        => 'footer_instagram_size',
			'label'           => esc_html__( 'Image Size', 'schematic' ),
			'section'         => 'footer',
			'default'         => 'small',
			'choices'         => array(
				'thumbnail' => esc_html__( 'Thumbnail', 'schematic' ),
				'small'     => esc_html__( 'Small', 'schematic' ),
				'large'     => esc_html__( 'Large', 'schematic' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_instagram_header',
			'label'           => esc_html__( 'Display header', 'schematic' ),
			'section'         => 'footer',
			'default'         => true,
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'              => 'text',
			'settings'          => 'footer_instagram_title',
			'label'             => esc_html__( 'Title', 'schematic' ),
			'section'           => 'footer',
			'default'           => esc_html__( 'Instagram', 'schematic' ),

			'sanitize_callback' => 'csco_kses',
			'active_callback'   => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
				array(
					'setting'  => 'footer_instagram_header',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'footer_instagram_type',
					'operator' => 'in',
					'value'    => array( 'type-2', 'type-3', 'type-4' ),
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_instagram_footer',
			'label'           => esc_html__( 'Display footer', 'schematic' ),
			'section'         => 'footer',
			'default'         => true,
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
				array(
					'setting'  => 'footer_instagram_type',
					'operator' => '===',
					'value'    => 'type-4',
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'footer_instagram_button',
			'label'           => esc_html__( 'Display follow button', 'schematic' ),
			'section'         => 'footer',
			'default'         => true,
			'active_callback' => array(
				array(
					'setting'  => 'footer_instagram_username',
					'operator' => '!=',
					'value'    => '',
				),
				array(
					'setting'  => 'footer_instagram_type',
					'operator' => 'in',
					'value'    => array( 'default', 'type-2', 'type-3' ),
				),
			),
		)
	);
}
