<?php
/**
 * Header Settings
 *
 * @package Schematic
 */

CSCO_Customizer::add_section(
	'header',
	array(
		'title' => esc_html__( 'Header Settings', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'header_collapsible_common',
		'section'     => 'header',
		'label'       => esc_html__( 'Common', 'schematic' ),
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'header_layout',
		'label'    => esc_html__( 'Layout', 'schematic' ),
		'section'  => 'header',
		'default'  => 'one',
		'choices'  => apply_filters( 'csco_header_layouts', array(
			'one'   => esc_html__( 'Header 1', 'schematic' ),
			'two'   => esc_html__( 'Header 2', 'schematic' ),
			'three' => esc_html__( 'Header 3', 'schematic' ),
		) ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'header_initial_height',
		'label'           => esc_html__( 'Header Initial Height', 'schematic' ),
		'section'         => 'header',
		'default'         => '96px',
		'output'          => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-initial-height',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => '!=',
				'value'    => 'cs-header-four',
			),
			array(
				'setting'  => 'header_layout',
				'operator' => '!=',
				'value'    => 'cs-header-five',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'dimension',
		'settings' => 'header_height',
		'label'    => esc_html__( 'Header Height', 'schematic' ),
		'section'  => 'header',
		'default'  => '60px',
		'output'   => array(
			array(
				'element'  => ':root',
				'property' => '--cs-header-height',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'checkbox',
		'settings'    => 'navbar_sticky',
		'label'       => esc_html__( 'Make navigation bar sticky', 'schematic' ),
		'description' => esc_html__( 'Enabling this option will make navigation bar visible when scrolling.', 'schematic' ),
		'section'     => 'header',
		'default'     => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'navbar_smart_sticky',
		'label'           => esc_html__( 'Enable the smart sticky feature', 'schematic' ),
		'description'     => esc_html__( 'Enabling this option will reveal navigation bar when scrolling up and hide it when scrolling down.', 'schematic' ),
		'section'         => 'header',
		'default'         => true,
		'active_callback' => array(
			array(
				'setting'  => 'navbar_sticky',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_navigation_menu',
		'label'           => esc_html__( 'Display navigation menu', 'schematic' ),
		'section'         => 'header',
		'default'         => true,
		'active_callback' => array(
			array(
				'setting'  => 'header_layout',
				'operator' => '!=',
				'value'    => 'two',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_offcanvas',
		'section'  => 'header',
		'label'    => esc_html__( 'Offcanvas', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_offcanvas',
		'label'    => esc_html__( 'Display offcanvas toggle button', 'schematic' ),
		'section'  => 'header',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'              => 'textarea',
		'settings'          => 'header_offcanvas_desc',
		'label'             => esc_html__( 'Offcanvas Description', 'schematic' ),
		'section'           => 'header',
		'default'           => '',
		'sanitize_callback' => 'csco_kses',
		'active_callback'   => array(
			array(
				'setting'  => 'header_offcanvas',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

/* Fullscreen Menu */
CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_fullscreen_menu',
		'section'  => 'header',
		'label'    => esc_html__( 'Fullscreen Menu', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_fullscreen_menu',
		'label'    => esc_html__( 'Display fullscreen menu toggle button', 'schematic' ),
		'section'  => 'header',
		'default'  => true,
	)
);

/* Fullscreen Posts */
CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_fullscreen_posts',
		'label'           => esc_html__( 'Display posts', 'schematic' ),
		'section'         => 'header',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);


CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_posts_heading',
		'label'           => esc_html__( 'Heading', 'schematic' ),
		'section'         => 'header',
		'default'         => esc_html__( 'The Latest', 'schematic' ),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_posts_label',
		'label'           => esc_html__( 'Link Label', 'schematic' ),
		'section'         => 'header',
		'default'         => esc_html__( 'View All', 'schematic' ),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_posts_url',
		'label'           => esc_html__( 'Link URL', 'schematic' ),
		'section'         => 'header',
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_fullscreen_preview_image',
		'label'           => esc_html__( 'Display preview image', 'schematic' ),
		'section'         => 'header',
		'default'         => true,
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'header_fullscreen_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'schematic' ),
		'section'         => 'header',
		'default'         => 'square',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'schematic' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
			'square'         => esc_html__( 'Square', 'schematic' ),
			'portrait'       => esc_html__( 'Portrait', 'schematic' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_preview_image',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'header_fullscreen_image_size',
		'label'           => esc_html__( 'Image Size', 'schematic' ),
		'section'         => 'header',
		'default'         => 'thumbnail',
		'choices'         => csco_get_list_available_image_sizes(),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_preview_image',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'header_fullscreen_image_border_radius',
		'label'           => esc_html__( 'Image Border Radius', 'schematic' ),
		'section'         => 'header',
		'default'         => '50%',
		'output'          => array(
			array(
				'element'  => '.cs-header__multi-column-posts .cs-entry__thumbnail',
				'property' => '--cs-thumbnail-border-radius',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_preview_image',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'multicheck',
		'settings'        => 'header_fullscreen_posts_meta',
		'label'           => esc_html__( 'Post Meta', 'schematic' ),
		'section'         => 'header',
		'default'         => array( 'date', 'comments' ),
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'schematic' ),
				'date'         => esc_html__( 'Date', 'schematic' ),
				'author'       => esc_html__( 'Author', 'schematic' ),
				'comments'     => esc_html__( 'Comments', 'schematic' ),
				'reading_time' => esc_html__( 'Reading Time', 'schematic' ),
				'views'        => esc_html__( 'Views', 'schematic' ),
				'shares'       => esc_html__( 'Shares', 'schematic' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_fullscreen_excerpt',
		'label'           => esc_html__( 'Display excerpt', 'schematic' ),
		'section'         => 'header',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_filter_posts',
		'label'           => esc_html__( 'Filter by Posts', 'schematic' ),
		'description'     => esc_html__( 'Add comma-separated list of post IDs. For example: 12, 34, 145. Leave empty for all posts.', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_filter_categories',
		'label'           => esc_html__( 'Filter by Categories', 'schematic' ),
		'description'     => esc_html__( 'Add comma-separated list of category slugs. For example: &laquo;travel, lifestyle, food&raquo;. Leave empty for all categories.', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_filter_tags',
		'label'           => esc_html__( 'Filter by Tags', 'schematic' ),
		'description'     => esc_html__( 'Add comma-separated list of tag slugs. For example: &laquo;worth-reading, top-5, playlists&raquo;. Leave empty for all tags.', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_fullscreen_posts_orderby',
		'label'           => esc_html__( 'Order posts by', 'schematic' ),
		'section'         => 'header',
		'default'         => 'date',
		'choices'         => array(
			'date'       => esc_html__( 'Date', 'schematic' ),
			'rand'       => esc_html__( 'Random', 'schematic' ),
			'name'       => esc_html__( 'Name', 'schematic' ),
			'post_views' => esc_html__( 'Views', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_fullscreen_time_frame',
		'label'           => esc_html__( 'Filter by Time Frame', 'schematic' ),
		'description'     => esc_html__( 'Add period of posts in English. For example: &laquo;2 months&raquo;, &laquo;14 days&raquo; or even &laquo;1 year&raquo;', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts_orderby',
				'operator' => '==',
				'value'    => 'post_views',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_fullscreen_posts_order',
		'label'           => esc_html__( 'Order posts', 'schematic' ),
		'section'         => 'header',
		'default'         => 'DESC',
		'choices'         => array(
			'ASC'  => esc_html__( 'ASC', 'schematic' ),
			'DESC' => esc_html__( 'DESC', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_fullscreen_menu',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_fullscreen_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_search',
		'section'  => 'header',
		'label'    => esc_html__( 'Search', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'header_search_display',
		'label'    => esc_html__( 'Display search button', 'schematic' ),
		'section'  => 'header',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_type',
		'label'           => esc_html__( 'Search type', 'schematic' ),
		'section'         => 'header',
		'default'         => 'one',
		'choices'         => apply_filters( 'csco_header_search_type', array(
			'one'   => esc_html__( 'Type 1', 'schematic' ),
			'two'   => esc_html__( 'Type 2', 'schematic' ),
			'three' => esc_html__( 'Type 3', 'schematic' ),
		) ),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

/* Tags */
CSCO_Customizer::add_field(
	array(
		'type'            => 'divider',
		'settings'        => wp_unique_id( 'divider' ),
		'section'         => 'header',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_tags',
		'label'           => esc_html__( 'Display tags', 'schematic' ),
		'section'         => 'header',
		'default'         => true,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_tags_heading',
		'label'           => esc_html__( 'Heading', 'schematic' ),
		'section'         => 'header',
		'default'         => esc_html__( 'Popular Topics', 'schematic' ),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'header_search_tags_number',
		'label'           => esc_html__( 'Maximum Number of Tags', 'schematic' ),
		'section'         => 'header',
		'default'         => 10,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_tags',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_tags_orderby',
		'label'           => esc_html__( 'Order tags by', 'schematic' ),
		'section'         => 'header',
		'default'         => 'date',
		'choices'         => array(
			'date'  => esc_html__( 'Date', 'schematic' ),
			'count' => esc_html__( 'Count of Posts', 'schematic' ),
			'name'  => esc_html__( 'Name', 'schematic' ),
			'id'    => esc_html__( 'ID', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_tags',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_tags_order',
		'label'           => esc_html__( 'Order tags', 'schematic' ),
		'section'         => 'header',
		'default'         => 'DESC',
		'choices'         => array(
			'ASC'  => esc_html__( 'ASC', 'schematic' ),
			'DESC' => esc_html__( 'DESC', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_tags',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

/* Posts */
CSCO_Customizer::add_field(
	array(
		'type'            => 'divider',
		'settings'        => wp_unique_id( 'divider' ),
		'section'         => 'header',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_posts',
		'label'           => esc_html__( 'Display posts', 'schematic' ),
		'section'         => 'header',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
		),
	)
);


CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_posts_heading',
		'label'           => esc_html__( 'Heading', 'schematic' ),
		'section'         => 'header',
		'default'         => esc_html__( 'The Latest', 'schematic' ),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_posts_label',
		'label'           => esc_html__( 'Link Label', 'schematic' ),
		'section'         => 'header',
		'default'         => esc_html__( 'View All', 'schematic' ),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_posts_url',
		'label'           => esc_html__( 'Link URL', 'schematic' ),
		'section'         => 'header',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_preview_image',
		'label'           => esc_html__( 'Display preview image', 'schematic' ),
		'section'         => 'header',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'header_search_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'schematic' ),
		'section'         => 'header',
		'default'         => 'landscape-16-9',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'schematic' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
			'square'         => esc_html__( 'Square', 'schematic' ),
			'portrait'       => esc_html__( 'Portrait', 'schematic' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_preview_image',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'header_search_image_size',
		'label'           => esc_html__( 'Image Size', 'schematic' ),
		'section'         => 'header',
		'default'         => 'csco-thumbnail',
		'choices'         => csco_get_list_available_image_sizes(),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_preview_image',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'dimension',
		'settings'        => 'header_search_image_border_radius',
		'label'           => esc_html__( 'Image Border Radius', 'schematic' ),
		'section'         => 'header',
		'default'         => '0',
		'output'          => array(
			array(
				'element'  => '.cs-search__posts .cs-entry__thumbnail',
				'property' => '--cs-thumbnail-border-radius',
			),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_preview_image',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'multicheck',
		'settings'        => 'header_search_posts_meta',
		'label'           => esc_html__( 'Post Meta', 'schematic' ),
		'section'         => 'header',
		'default'         => array( 'date', 'comments' ),
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'schematic' ),
				'date'         => esc_html__( 'Date', 'schematic' ),
				'author'       => esc_html__( 'Author', 'schematic' ),
				'comments'     => esc_html__( 'Comments', 'schematic' ),
				'reading_time' => esc_html__( 'Reading Time', 'schematic' ),
				'views'        => esc_html__( 'Views', 'schematic' ),
				'shares'       => esc_html__( 'Shares', 'schematic' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'header_search_excerpt',
		'label'           => esc_html__( 'Display excerpt', 'schematic' ),
		'section'         => 'header',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_filter_posts',
		'label'           => esc_html__( 'Filter by Posts', 'schematic' ),
		'description'     => esc_html__( 'Add comma-separated list of post IDs. For example: 12, 34, 145. Leave empty for all posts.', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_filter_categories',
		'label'           => esc_html__( 'Filter by Categories', 'schematic' ),
		'description'     => esc_html__( 'Add comma-separated list of category slugs. For example: &laquo;travel, lifestyle, food&raquo;. Leave empty for all categories.', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_filter_tags',
		'label'           => esc_html__( 'Filter by Tags', 'schematic' ),
		'description'     => esc_html__( 'Add comma-separated list of tag slugs. For example: &laquo;worth-reading, top-5, playlists&raquo;. Leave empty for all tags.', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_posts_orderby',
		'label'           => esc_html__( 'Order posts by', 'schematic' ),
		'section'         => 'header',
		'default'         => 'date',
		'choices'         => array(
			'date'       => esc_html__( 'Date', 'schematic' ),
			'rand'       => esc_html__( 'Random', 'schematic' ),
			'name'       => esc_html__( 'Name', 'schematic' ),
			'post_views' => esc_html__( 'Views', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'text',
		'settings'        => 'header_search_time_frame',
		'label'           => esc_html__( 'Filter by Time Frame', 'schematic' ),
		'description'     => esc_html__( 'Add period of posts in English. For example: &laquo;2 months&raquo;, &laquo;14 days&raquo; or even &laquo;1 year&raquo;', 'schematic' ),
		'section'         => 'header',
		'default'         => '',
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_posts_orderby',
				'operator' => '==',
				'value'    => 'post_views',
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'header_search_posts_order',
		'label'           => esc_html__( 'Order posts', 'schematic' ),
		'section'         => 'header',
		'default'         => 'DESC',
		'choices'         => array(
			'ASC'  => esc_html__( 'ASC', 'schematic' ),
			'DESC' => esc_html__( 'DESC', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'header_search_display',
				'operator' => '==',
				'value'    => true,
			),
			array(
				'setting'  => 'header_search_type',
				'operator' => '==',
				'value'    => 'one',
			),
			array(
				'setting'  => 'header_search_posts',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

if ( csco_powerkit_module_enabled( 'social_links' ) ) {
	CSCO_Customizer::add_field(
		array(
			'type'     => 'collapsible',
			'settings' => 'header_collapsible_social_links',
			'section'  => 'header',
			'label'    => esc_html__( 'Social Links', 'schematic' ),

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'     => 'checkbox',
			'settings' => 'header_social_links',
			'label'    => esc_html__( 'Display social links', 'schematic' ),
			'section'  => 'header',
			'default'  => false,

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'select',
			'settings'        => 'header_social_links_scheme',
			'label'           => esc_html__( 'Color scheme', 'schematic' ),
			'section'         => 'header',
			'default'         => 'light',
			'choices'         => array(
				'light' => esc_html__( 'Light', 'schematic' ),
				'bold'  => esc_html__( 'Bold', 'schematic' ),
			),
			'active_callback' => array(
				array(
					'setting'  => 'header_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'number',
			'settings'        => 'header_social_links_maximum',
			'label'           => esc_html__( 'Maximum Number of Social Links', 'schematic' ),
			'section'         => 'header',
			'default'         => 3,
			'active_callback' => array(
				array(
					'setting'  => 'header_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'header_social_links_counts',
			'label'           => esc_html__( 'Display social counts', 'schematic' ),
			'section'         => 'header',
			'default'         => true,
			'active_callback' => array(
				array(
					'setting'  => 'header_social_links',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_link',
		'section'  => 'header',
		'label'    => esc_html__( 'Custom Link', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'text',
		'settings' => 'header_link_url',
		'label'    => esc_html__( 'URL', 'schematic' ),
		'section'  => 'header',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'              => 'text',
		'settings'          => 'header_link_label',
		'label'             => esc_html__( 'Label', 'schematic' ),
		'section'           => 'header',
		'sanitize_callback' => 'csco_kses',
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'header_collapsible_mega_menu',
		'section'  => 'header',
		'label'    => esc_html__( 'Mega Menu', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'select',
		'settings' => 'mega_menu_image_orientation',
		'label'    => esc_html__( 'Image Orientation', 'schematic' ),
		'section'  => 'header',
		'default'  => 'landscape-3-2',
		'choices'  => array(
			'original'       => esc_html__( 'Original', 'schematic' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
			'portrait'       => esc_html__( 'Portrait 3:4', 'schematic' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
			'square'         => esc_html__( 'Square', 'schematic' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'select',
		'settings' => 'mega_menu_image_size',
		'label'    => esc_html__( 'Image Size', 'schematic' ),
		'section'  => 'header',
		'default'  => 'csco-thumbnail',
		'choices'  => csco_get_list_available_image_sizes(),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'multicheck',
		'settings' => 'mega_menu_post_meta',
		'label'    => esc_html__( 'Post Meta', 'schematic' ),
		'section'  => 'header',
		'default'  => array( 'category', 'author', 'views', 'shares' ),
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'schematic' ),
				'date'         => esc_html__( 'Date', 'schematic' ),
				'author'       => esc_html__( 'Author', 'schematic' ),
				'reading_time' => esc_html__( 'Reading Time', 'schematic' ),
				'comments'     => esc_html__( 'Comments', 'schematic' ),
				'views'        => esc_html__( 'Views', 'schematic' ),
				'shares'       => esc_html__( 'Shares', 'schematic' ),
			)
		),
	)
);
