<?php
/**
 * Post Settings
 *
 * @package Schematic
 */

CSCO_Customizer::add_section(
	'post_settings',
	array(
		'title' => esc_html__( 'Post Settings', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'        => 'collapsible',
		'settings'    => 'post_collapsible_common',
		'section'     => 'post_settings',
		'label'       => esc_html__( 'Common', 'schematic' ),
		'input_attrs' => array(
			'collapsed' => true,
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'post_sidebar',
		'label'    => esc_html__( 'Default Sidebar', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => 'right',
		'choices'  => array(
			'right'    => esc_html__( 'Right Sidebar', 'schematic' ),
			'left'     => esc_html__( 'Left Sidebar', 'schematic' ),
			'disabled' => esc_html__( 'No Sidebar', 'schematic' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'multicheck',
		'settings' => 'post_meta',
		'label'    => esc_html__( 'Post Meta', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => array( 'category', 'author', 'reading_time', 'views' ),
		'choices'  => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'schematic' ),
				'date'         => esc_html__( 'Date', 'schematic' ),
				'author'       => esc_html__( 'Author', 'schematic' ),
				'comments'     => esc_html__( 'Comments', 'schematic' ),
				'reading_time' => esc_html__( 'Reading Time', 'schematic' ),
				'views'        => esc_html__( 'Views', 'schematic' ),
				'shares'       => esc_html__( 'Shares', 'schematic' ),
			)
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'radio',
		'settings' => 'post_header_type',
		'label'    => esc_html__( 'Default Page Header Type', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => 'standard',
		'choices'  => array(
			'standard'    => esc_html__( 'Standard', 'schematic' ),
			'large'       => esc_html__( 'Large', 'schematic' ),
			'large-media' => esc_html__( 'Large Media', 'schematic' ),
			'full'        => esc_html__( 'Full', 'schematic' ),
			'title'       => esc_html__( 'Page Title Only', 'schematic' ),
			'none'        => esc_html__( 'None', 'schematic' ),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'radio',
		'settings'        => 'post_media_preview',
		'label'           => esc_html__( 'Standard Page Header Preview', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => 'uncropped',
		'choices'         => array(
			'cropped'   => esc_html__( 'Display Cropped Image', 'schematic' ),
			'uncropped' => esc_html__( 'Display Preview in Original Ratio', 'schematic' ),
		),
		'active_callback' => array(
			array(
				array(
					'setting'  => 'post_header_type',
					'operator' => '==',
					'value'    => 'standard',
				),
				array(
					'setting'  => 'post_header_type',
					'operator' => '==',
					'value'    => 'grid',
				),
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_excerpt',
		'label'    => esc_html__( 'Display excerpts', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_subtitle',
		'label'    => esc_html__( 'Display excerpt as post subtitle', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_author',
		'label'    => esc_html__( 'Display post author', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => false,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_tags',
		'label'    => esc_html__( 'Display tags', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => false,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_comments_simple',
		'label'    => esc_html__( 'Display comments without the View Comments button', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => true,
	)
);

if ( csco_powerkit_module_enabled( 'opt_in_forms' ) ) {
	CSCO_Customizer::add_field(
		array(
			'type'     => 'collapsible',
			'settings' => 'post_collapsible_subscription_form',
			'section'  => 'post_settings',
			'label'    => esc_html__( 'Subscription Form', 'schematic' ),

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'     => 'checkbox',
			'settings' => 'post_subscribe',
			'label'    => esc_html__( 'Display subscribe section', 'schematic' ),
			'section'  => 'post_settings',
			'default'  => false,

		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'checkbox',
			'settings'        => 'post_subscribe_name',
			'label'           => esc_html__( 'Display first name field', 'schematic' ),
			'section'         => 'post_settings',
			'default'         => false,
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'text',
			'settings'        => 'post_subscribe_title',
			'label'           => esc_html__( 'Title', 'schematic' ),
			'section'         => 'post_settings',
			'default'         => esc_html__( 'Subscribe to our newsletter and get posts every week', 'schematic' ),
			'active_callback' => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'              => 'text',
			'settings'          => 'post_subscribe_text',
			'label'             => esc_html__( 'Text', 'schematic' ),
			'section'           => 'post_settings',
			'default'           => esc_html__( 'Get notified of the best deals on our WordPress themes.', 'schematic' ),
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => array(
				array(
					'setting'  => 'post_subscribe',
					'operator' => '==',
					'value'    => true,
				),
			),
		)
	);
}

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_related_posts',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Related Posts', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'related',
		'label'    => esc_html__( 'Display related section', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => false,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'related_image_orientation',
		'label'           => esc_html__( 'Image Orientation', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => 'original',
		'choices'         => array(
			'original'       => esc_html__( 'Original', 'schematic' ),
			'landscape'      => esc_html__( 'Landscape 4:3', 'schematic' ),
			'landscape-3-2'  => esc_html__( 'Landscape 3:2', 'schematic' ),
			'landscape-16-9' => esc_html__( 'Landscape 16:9', 'schematic' ),
			'portrait'       => esc_html__( 'Portrait 3:4', 'schematic' ),
			'portrait-2-3'   => esc_html__( 'Portrait 2:3', 'schematic' ),
			'square'         => esc_html__( 'Square', 'schematic' ),
		),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'select',
		'settings'        => 'related_image_size',
		'label'           => esc_html__( 'Image Size', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => 'csco-thumbnail',
		'choices'         => csco_get_list_available_image_sizes(),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'multicheck',
		'settings'        => 'related_post_meta',
		'label'           => esc_html__( 'Post Meta', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => array( 'author', 'date' ),
		'choices'         => apply_filters(
			'csco_post_meta_choices',
			array(
				'category'     => esc_html__( 'Category', 'schematic' ),
				'date'         => esc_html__( 'Date', 'schematic' ),
				'author'       => esc_html__( 'Author', 'schematic' ),
				'comments'     => esc_html__( 'Comments', 'schematic' ),
				'reading_time' => esc_html__( 'Reading Time', 'schematic' ),
				'views'        => esc_html__( 'Views', 'schematic' ),
				'shares'       => esc_html__( 'Shares', 'schematic' ),
			)
		),
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'related_compact_post_meta',
		'label'           => esc_html__( 'Display compact post meta', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => true,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'number',
		'settings'        => 'related_number',
		'label'           => esc_html__( 'Maximum Number of Related Posts', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => 4,
		'active_callback' => array(
			array(
				'setting'  => 'related',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

if ( csco_post_views_enabled() ) {

	CSCO_Customizer::add_field(
		array(
			'type'     => 'radio',
			'settings' => 'related_orderby',
			'label'    => esc_html__( 'Order posts by', 'schematic' ),
			'section'  => 'post_settings',
			'default'  => 'date',
			'choices'  => array(
				'date'       => esc_html__( 'Date', 'schematic' ),
				'post_views' => esc_html__( 'Views', 'schematic' ),
				'rand'       => esc_html__( 'Rand', 'schematic' ),
			),
		)
	);

	CSCO_Customizer::add_field(
		array(
			'type'            => 'text',
			'settings'        => 'related_time_frame',
			'label'           => esc_html__( 'Time Frame', 'schematic' ),
			'description'     => esc_html__( 'Add period of posts in English. For example: &laquo;2 months&raquo;, &laquo;14 days&raquo; or even &laquo;1 year&raquo;', 'schematic' ),
			'section'         => 'post_settings',
			'default'         => '',
			'active_callback' => array(
				array(
					'setting'  => 'related',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'setting'  => 'related_orderby',
					'operator' => '==',
					'value'    => 'post_views',
				),
			),
		)
	);
}

CSCO_Customizer::add_field(
	array(
		'type'     => 'collapsible',
		'settings' => 'post_collapsible_load_nextpost',
		'section'  => 'post_settings',
		'label'    => esc_html__( 'Auto Load Next Post', 'schematic' ),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'     => 'checkbox',
		'settings' => 'post_load_nextpost',
		'label'    => esc_html__( 'Enable the Auto Load Next Post feature', 'schematic' ),
		'section'  => 'post_settings',
		'default'  => false,
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_same_category',
		'label'           => esc_html__( 'Auto load posts from the same category only', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);

CSCO_Customizer::add_field(
	array(
		'type'            => 'checkbox',
		'settings'        => 'post_load_nextpost_reverse',
		'label'           => esc_html__( 'Auto load previous posts instead of next ones', 'schematic' ),
		'section'         => 'post_settings',
		'default'         => false,
		'active_callback' => array(
			array(
				'setting'  => 'post_load_nextpost',
				'operator' => '==',
				'value'    => true,
			),
		),
	)
);
