<?php
/**
 * Block Tile Type 2
 *
 * @var        $attributes - block attributes
 * @var        $options - layout options
 * @var        $posts - all available posts
 *
 * @package Schematic
 */

$options['withoutLink'] = true;
$options['image_size']  = true;

// Check if there're enough posts in the query.
if ( $posts->have_posts() ) {
	$posts->the_post();

	$primary_post_id = get_the_ID();
	?>
	<div class="<?php echo esc_attr( $attributes['className'] ); ?>">
		<div class="cnvs-block-posts-inner">
			<div class="cnvs-block-layout__wrap cs-overlay-ratio cs-ratio-wide cs-video-wrap" data-scheme="inverse">

			<?php
			if ( has_post_thumbnail() ) {
				cnvs_block_post_overlay_thumbnail( $options, $attributes );
			}
			?>

			<div class="cs-container">
				<div class="cnvs-block-layout__inner cs-overlay-content">
					<div class="cnvs-block-layout__item">
						<div class="cs-entry__post-meta-wrapper">
							<?php cnvs_block_post_meta( $options, array( 'category', 'date', 'comments', 'reading_time', 'views' ) ); ?>

							<?php
								cnvs_block_post_meta( array_merge( $options, array(
									'meta-settings' => array(
										'wrap_class'     => 'cs-entry__post-meta-line',
										'disable_scheme' => true,
									),
								) ), array( 'shares' ) );
							?>
						</div>
						<?php cnvs_block_post_title( $options ); ?>

						<div class="cs-entry__post-meta-wrapper">
							<?php cnvs_block_post_author( $options ); ?>

							<?php cnvs_block_post_video_controls( $options ); ?>
						</div>
					</div>


					<div class="cnvs-block-layout__sub-item">
						<?php
						$heading      = $options['heading'];
						$heading_args = array(
							'link_label'   => $options['heading_label'],
							'link_url'     => $options['heading_url'],
							'global_style' => false,
						);
						?>
						<?php csco_section_heading( $heading, 'full', true, '', 'default', $heading_args ); ?>
							<div class="cnvs-block-layout__row">

								<?php
								while ( $posts->have_posts() ) {
									$posts->the_post();

									$options['video'] = false;

									$options['small_image_size'] = 'csco-small';

									?>
									<div class="cnvs-block-layout__col">
										<article <?php post_class(); ?>>
											<div class="cs-entry__outer">
												<div class="cs-entry__inner cs-entry__content">
													<?php
														cnvs_block_post_meta( array_merge( $options, array(
															'meta-settings' => array(
																'prefix' => 'small',
															),
														) ), array( 'category', 'date', 'author', 'comments', 'reading_time', 'views', 'shares' ) );
													?>
													<div class="cs-entry__content-inner">
														<?php cnvs_block_post_title( $options, 'small' ); ?>
													</div>
												</div>
												<?php cnvs_block_post_thumbnail( $options, $attributes, 'small' ); ?>
												<a href="<?php echo esc_url( get_the_permalink() ); ?>" class="cs-overlay-link"></a>
											</div>
										</article>
									</div>
									<?php
								}
								?>
							</div>
						</div>
					</div>
				</div>
				<a href="<?php echo esc_url( get_the_permalink( $primary_post_id ) ); ?>" class="cs-overlay-link"></a>
			</div>
		</div>
	</div>
	<?php
	wp_reset_postdata();
} else {
	cnvs_alert_warning( esc_html__( 'There aren\'t enough posts that match the filter criteria.', 'schematic' ) );
}
