<?php
/**
 * The template part for displaying off-canvas area.
 *
 * @package Schematic
 */

if ( csco_offcanvas_exists() ) {

	$scheme = csco_color_scheme(
		get_theme_mod( 'color_offcanvas_background', '#F8F8F8' ),
		get_theme_mod( 'color_offcanvas_background_dark', '#292929' )
	);
	?>

	<div class="cs-site-overlay"></div>

	<div class="cs-offcanvas">
		<div class="cs-offcanvas__outer" <?php echo wp_kses( $scheme, 'csco' ); ?>>
			<span class="cs-offcanvas__toggle">
				<span class="cs-offcanvas__toggle-icon"></span>
			</span>

			<aside class="cs-offcanvas__sidebar">
				<div class="cs-offcanvas__inner cs-offcanvas__area cs-widget-area">

					<div class="cs-offcanvas__header">
						<nav class="cs-offcanvas__nav">
							<?php csco_component( 'header_logo' ); ?>
						</nav>

						<?php
						$offcanvas_desc = get_theme_mod( 'header_offcanvas_desc' );
						if ( $offcanvas_desc ) {
							?>
							<div class="cs-offcanvas__desc">
								<?php echo do_shortcode( $offcanvas_desc ); ?>
							</div>
							<?php
						}
						?>
					</div>

					<?php
					$locations = get_nav_menu_locations();

					// Mobile.
					if ( isset( $locations['primary'] ) || isset( $locations['mobile'] ) ) {

						if ( isset( $locations['primary'] ) ) {
							$location = $locations['primary'];
						}
						if ( isset( $locations['mobile'] ) ) {
							$location = $locations['mobile'];
						}

						the_widget( 'WP_Nav_Menu_Widget', array( 'nav_menu' => $location ), array(
							'before_widget' => '<div class="widget %s cs-d-lg-none">',
							'after_widget'  => '</div>',
						) );
					}

					// Offcanvas.
					if ( has_nav_menu( 'offcanvas' ) ) {

						class CSCO_Offcanvas_Walker extends Walker_Nav_Menu {
							/**
							 * Starts the element output.
							 *
							 * @since 3.0.0
							 * @since 4.4.0 The {@see 'nav_menu_item_args'} filter was added.
							 * @since 5.9.0 Renamed `$item` to `$data_object` and `$id` to `$current_object_id`
							 *              to match parent class for PHP 8 named parameter support.
							 *
							 * @see Walker::start_el()
							 *
							 * @param string   $output            Used to append additional content (passed by reference).
							 * @param WP_Post  $data_object       Menu item data object.
							 * @param int      $depth             Depth of menu item. Used for padding.
							 * @param stdClass $args              An object of wp_nav_menu() arguments.
							 * @param int      $current_object_id Optional. ID of the current menu item. Default 0.
							 */
							public function start_el( &$output, $data_object, $depth = 0, $args = null, $current_object_id = 0 ) {

								$offcanvas_posts = __return_empty_string();

								if ( 'category' === $data_object->object ) {
									ob_start();

									$posts_args = array(
										'post_type'      => 'post',
										'posts_per_page' => 6,
										'tax_query'      => array(
											array(
												'taxonomy' => 'category',
												'field'    => 'id',
												'terms'    => $data_object->object_id,
											),
										),
									);

									$query = new WP_Query( $posts_args );

									if ( $query->have_posts() ) {

										$scheme = csco_color_scheme( '#141414', '#ffffff' );

										$category_object = get_term( $data_object->object_id, 'category' );
										?>
										<div class="cs-offcanvas-posts-container" <?php echo wp_kses( $scheme, 'csco' ); ?>>
											<div class="cs-offcanvas-posts-title">
												<?php esc_html_e( 'Latest in ', 'schematic' ); ?>

												<?php echo esc_html( $category_object->name ); ?>
											</div>
											<div class="cs-offcanvas-posts-list">
												<?php
												$counter = 0;
												while ( $query->have_posts() ) {
													$query->the_post();

													$counter++;

													if ( 1 === $counter ) {
														?>
														<article <?php post_class( 'cs-offcanvas-posts-list__item cs-offcanvas-posts-list__large' ); ?>>
															<div class="cs-entry__outer">
																<?php if ( has_post_thumbnail() ) { ?>
																	<div class="cs-entry__inner cs-entry__overlay cs-entry__thumbnail cs-overlay-ratio cs-ratio-landscape">
																		<div class="cs-overlay-background cs-overlay-transparent">
																			<?php the_post_thumbnail( 'csco-thumbnail' ); ?>
																		</div>

																		<a href="<?php echo esc_url( get_permalink() ); ?>" class="cs-overlay-link"></a>
																	</div>
																<?php } ?>

																<div class="cs-entry__inner cs-entry__content">
																	<?php the_title( '<h4 class="cs-entry__title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h4>' ); ?>

																	<?php csco_entry_meta_author( array( 'author' ) ); ?>
																</div>
															</div>
														</article>
														<?php
													} else {
														?>
														<article <?php post_class( 'cs-offcanvas-posts-list__item cs-offcanvas-posts-list__small' ); ?>>
															<div class="cs-entry__outer">
																<div class="cs-entry__inner cs-entry__content">
																	<?php the_title( '<h4 class="cs-entry__title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h4>' ); ?>
																</div>
															</div>
														</article>
														<?php
													}
												}
												?>
											</div>
										</div>
										<?php
									}

									wp_reset_postdata();

									$offcanvas_posts .= ob_get_clean();
								}

								// Restores the more descriptive, specific name for use within this method.
								$menu_item = $data_object;

								if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
									$t = '';
									$n = '';
								} else {
									$t = "\t";
									$n = "\n";
								}
								$indent = ( $depth ) ? str_repeat( $t, $depth ) : '';

								$classes   = empty( $menu_item->classes ) ? array() : (array) $menu_item->classes;
								$classes[] = 'menu-item-' . $menu_item->ID;

								/**
								 * Filters the arguments for a single nav menu item.
								 *
								 * @since 4.4.0
								 *
								 * @param stdClass $args      An object of wp_nav_menu() arguments.
								 * @param WP_Post  $menu_item Menu item data object.
								 * @param int      $depth     Depth of menu item. Used for padding.
								 */
								$args = apply_filters( 'nav_menu_item_args', $args, $menu_item, $depth );

								/**
								 * Filters the CSS classes applied to a menu item's list item element.
								 *
								 * @since 3.0.0
								 * @since 4.1.0 The `$depth` parameter was added.
								 *
								 * @param string[] $classes   Array of the CSS classes that are applied to the menu item's `<li>` element.
								 * @param WP_Post  $menu_item The current menu item object.
								 * @param stdClass $args      An object of wp_nav_menu() arguments.
								 * @param int      $depth     Depth of menu item. Used for padding.
								 */
								$class_names = implode( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $menu_item, $args, $depth ) );

								if ( $offcanvas_posts ) {
									$class_names .= ' cs-offcanvas-posts';
								}

								$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

								/**
								 * Filters the ID applied to a menu item's list item element.
								 *
								 * @since 3.0.1
								 * @since 4.1.0 The `$depth` parameter was added.
								 *
								 * @param string   $menu_id   The ID that is applied to the menu item's `<li>` element.
								 * @param WP_Post  $menu_item The current menu item.
								 * @param stdClass $args      An object of wp_nav_menu() arguments.
								 * @param int      $depth     Depth of menu item. Used for padding.
								 */
								$id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $menu_item->ID, $menu_item, $args, $depth );
								$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

								$output .= $indent . '<li' . $id . $class_names . '>';

								$atts           = array();
								$atts['title']  = ! empty( $menu_item->attr_title ) ? $menu_item->attr_title : '';
								$atts['target'] = ! empty( $menu_item->target ) ? $menu_item->target : '';
								if ( '_blank' === $menu_item->target && empty( $menu_item->xfn ) ) {
									$atts['rel'] = 'noopener';
								} else {
									$atts['rel'] = $menu_item->xfn;
								}
								$atts['href']         = ! empty( $menu_item->url ) ? $menu_item->url : '';
								$atts['aria-current'] = $menu_item->current ? 'page' : '';

								/**
								 * Filters the HTML attributes applied to a menu item's anchor element.
								 *
								 * @since 3.6.0
								 * @since 4.1.0 The `$depth` parameter was added.
								 *
								 * @param array $atts {
								 *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
								 *
								 *     @type string $title        Title attribute.
								 *     @type string $target       Target attribute.
								 *     @type string $rel          The rel attribute.
								 *     @type string $href         The href attribute.
								 *     @type string $aria-current The aria-current attribute.
								 * }
								 * @param WP_Post  $menu_item The current menu item object.
								 * @param stdClass $args      An object of wp_nav_menu() arguments.
								 * @param int      $depth     Depth of menu item. Used for padding.
								 */
								$atts = apply_filters( 'nav_menu_link_attributes', $atts, $menu_item, $args, $depth );

								$attributes = '';
								foreach ( $atts as $attr => $value ) {
									if ( is_scalar( $value ) && '' !== $value && false !== $value ) {
										$value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
										$attributes .= ' ' . $attr . '="' . $value . '"';
									}
								}

								/** This filter is documented in wp-includes/post-template.php */
								$title = apply_filters( 'the_title', $menu_item->title, $menu_item->ID );

								/**
								 * Filters a menu item's title.
								 *
								 * @since 4.4.0
								 *
								 * @param string   $title     The menu item's title.
								 * @param WP_Post  $menu_item The current menu item object.
								 * @param stdClass $args      An object of wp_nav_menu() arguments.
								 * @param int      $depth     Depth of menu item. Used for padding.
								 */
								$title = apply_filters( 'nav_menu_item_title', $title, $menu_item, $args, $depth );

								$item_output  = $args->before;
								$item_output .= '<a' . $attributes . '>';
								$item_output .= $args->link_before . $title . $args->link_after;
								$item_output .= '</a>';
								$item_output .= $args->after;

								if ( $offcanvas_posts ) {
									$item_output .= $offcanvas_posts;
								}

								/**
								 * Filters a menu item's starting output.
								 *
								 * The menu item's starting output only includes `$args->before`, the opening `<a>`,
								 * the menu item's title, the closing `</a>`, and `$args->after`. Currently, there is
								 * no filter for modifying the opening and closing `<li>` for a menu item.
								 *
								 * @since 3.0.0
								 *
								 * @param string   $item_output The menu item's starting HTML output.
								 * @param WP_Post  $menu_item   Menu item data object.
								 * @param int      $depth       Depth of menu item. Used for padding.
								 * @param stdClass $args        An object of wp_nav_menu() arguments.
								 */
								$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $menu_item, $depth, $args );
							}

							/**
							 * Ends the element output, if needed.
							 *
							 * @since 3.0.0
							 * @since 5.9.0 Renamed `$item` to `$data_object` to match parent class for PHP 8 named parameter support.
							 *
							 * @see Walker::end_el()
							 *
							 * @param string   $output      Used to append additional content (passed by reference).
							 * @param WP_Post  $data_object Menu item data object. Not used.
							 * @param int      $depth       Depth of page. Not Used.
							 * @param stdClass $args        An object of wp_nav_menu() arguments.
							 */
							public function end_el( &$output, $data_object, $depth = 0, $args = null ) {
								if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
									$t = '';
									$n = '';
								} else {
									$t = "\t";
									$n = "\n";
								}
								$output .= "</li>{$n}";
							}
						}

						?>
						<div class="widget widget_nav_menu">
							<?php
							wp_nav_menu(
								array(
									'theme_location' => 'offcanvas',
									'walker'         => new CSCO_Offcanvas_Walker(),
								)
							);
							?>
						</div>
						<?php
					}
					?>

					<?php dynamic_sidebar( 'sidebar-offcanvas' ); ?>
				</div>
			</aside>
		</div>
	</div>
	<?php
}
